#!/usr/bin/env python
# -*- coding: utf-8 -*-
# cdd.py - CCD editor for MLHIM.
# (c) 2012 - Timothy w.Cook & Contributors. (see: credits)

licenseText = """
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

credits = ["Eduardo C. P. Ribeiro", "Timothy W.Cook", "Luciana Tricai Cavalini"]

import sys
import os
import locale
import ConfigParser
import uuid
import gettext
from xml.sax.saxutils import escape

import wx
import wx.lib.mixins.listctrl as listmix
from wx import SpinCtrl, CheckListBox
from wx.lib.wordwrap import wordwrap
from wx.gizmos import EditableListBox

gettext.bindtextdomain('CDD','locale/en')
gettext.textdomain('CDD')
_ = gettext.gettext


#import cdg_main
#import cdd_version

# begin wxGlade: extracode
# end wxGlade

class Slot(wx.Panel):
    def __init__(self, *args, **kwds):
        # begin wxGlade: Slot.__init__
        kwds["style"] = wx.TAB_TRAVERSAL
        wx.Panel.__init__(self, *args, **kwds)
        self.check_list_box_slot = CheckListBox(self, -1)
        self.label_slot = wx.StaticText(self, -1, _("Enter the CCD Id:"))
        self.text_ctrl_ccd = wx.TextCtrl(self, -1, "")
        self.button_ccd_remove = wx.Button(self, -1, _("Remove"))
        self.button_ccd_add = wx.Button(self, -1, _("Add"))
        self.sizer_74_staticbox = wx.StaticBox(self, -1, _("Enter the desired CCD Ids and click Add"))

        self.__set_properties()
        self.__do_layout()

        self.Bind(wx.EVT_BUTTON, self.ccd_remove, self.button_ccd_remove)
        self.Bind(wx.EVT_BUTTON, self.ccd_add, self.button_ccd_add)
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: Slot.__set_properties
        pass
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: Slot.__do_layout
        self.sizer_74_staticbox.Lower()
        sizer_74 = wx.StaticBoxSizer(self.sizer_74_staticbox, wx.HORIZONTAL)
        sizer_75 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_76 = wx.BoxSizer(wx.VERTICAL)
        sizer_77 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_75.Add(self.check_list_box_slot, 1, wx.EXPAND, 0)
        sizer_75.Add((20, 20), 0, wx.EXPAND, 0)
        sizer_76.Add(self.label_slot, 0, 0, 0)
        sizer_76.Add(self.text_ctrl_ccd, 0, wx.EXPAND, 0)
        sizer_77.Add(self.button_ccd_remove, 0, 0, 0)
        sizer_77.Add((20, 20), 1, wx.EXPAND, 0)
        sizer_77.Add(self.button_ccd_add, 0, 0, 0)
        sizer_76.Add(sizer_77, 0, wx.EXPAND, 0)
        sizer_76.Add((20, 20), 1, wx.EXPAND, 0)
        sizer_75.Add(sizer_76, 1, wx.EXPAND, 0)
        sizer_75.Add((20, 20), 0, wx.EXPAND, 0)
        sizer_74.Add(sizer_75, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_74)
        sizer_74.Fit(self)
        # end wxGlade

    def ccd_add(self, event):  # wxGlade: Slot.<event_handler>
        cdd_id = self.text_ctrl_ccd.GetValue()
        self.check_list_box_slot.Append(cdd_id)
        self.text_ctrl_ccd.Clear()

    def ccd_remove(self, event):  # wxGlade: Slot.<event_handler>
        pos = self.check_list_box_slot.GetSelection()
        if pos >= 0:
            self.check_list_box_slot.Delete(pos)

# end of class Slot
class PartySelf(wx.Panel):
    def __init__(self, *args, **kwds):
        # begin wxGlade: PartySelf.__init__
        kwds["style"] = wx.TAB_TRAVERSAL
        wx.Panel.__init__(self, *args, **kwds)
        self.text_ctrl_external_ref = wx.TextCtrl(self, -1, "")
        self.sizer_65_staticbox = wx.StaticBox(self, -1, _("external_ref"))
        self.text_ctrl_feeder_audit = wx.TextCtrl(self, -1, "")
        self.sizer_66_staticbox = wx.StaticBox(self, -1, _("feeder_audit"))

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: PartySelf.__set_properties
        pass
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: PartySelf.__do_layout
        sizer_60 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_61 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_66_staticbox.Lower()
        sizer_66 = wx.StaticBoxSizer(self.sizer_66_staticbox, wx.HORIZONTAL)
        self.sizer_65_staticbox.Lower()
        sizer_65 = wx.StaticBoxSizer(self.sizer_65_staticbox, wx.HORIZONTAL)
        sizer_65.Add(self.text_ctrl_external_ref, 1, 0, 0)
        sizer_61.Add(sizer_65, 1, 0, 0)
        sizer_66.Add(self.text_ctrl_feeder_audit, 1, 0, 0)
        sizer_61.Add(sizer_66, 1, 0, 0)
        sizer_60.Add(sizer_61, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_60)
        sizer_60.Fit(self)
        # end wxGlade

# end of class PartySelf

class PartyIdentified(wx.Panel):
    def __init__(self, *args, **kwds):
        # begin wxGlade: PartyIdentified.__init__
        kwds["style"] = wx.TAB_TRAVERSAL
        wx.Panel.__init__(self, *args, **kwds)
        self.text_ctrl_details = wx.TextCtrl(self, -1, "")
        self.sizer_56_staticbox = wx.StaticBox(self, -1, _("details"))
        self.text_ctrl_party_name = wx.TextCtrl(self, -1, "")
        self.sizer_57_staticbox = wx.StaticBox(self, -1, _("party_name"))
        self.text_ctrl_feeder_audit = wx.TextCtrl(self, -1, "")
        self.sizer_58_staticbox = wx.StaticBox(self, -1, _("feeder_audit"))
        self.text_ctrl_external_ref = wx.TextCtrl(self, -1, "")
        self.sizer_59_staticbox = wx.StaticBox(self, -1, _("external_ref"))

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: PartyIdentified.__set_properties
        pass
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: PartyIdentified.__do_layout
        sizer_51 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_67 = wx.BoxSizer(wx.VERTICAL)
        sizer_69 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_59_staticbox.Lower()
        sizer_59 = wx.StaticBoxSizer(self.sizer_59_staticbox, wx.HORIZONTAL)
        self.sizer_58_staticbox.Lower()
        sizer_58 = wx.StaticBoxSizer(self.sizer_58_staticbox, wx.HORIZONTAL)
        sizer_68 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_57_staticbox.Lower()
        sizer_57 = wx.StaticBoxSizer(self.sizer_57_staticbox, wx.HORIZONTAL)
        self.sizer_56_staticbox.Lower()
        sizer_56 = wx.StaticBoxSizer(self.sizer_56_staticbox, wx.HORIZONTAL)
        sizer_56.Add(self.text_ctrl_details, 1, 0, 0)
        sizer_68.Add(sizer_56, 1, 0, 0)
        sizer_57.Add(self.text_ctrl_party_name, 1, 0, 0)
        sizer_68.Add(sizer_57, 1, 0, 0)
        sizer_67.Add(sizer_68, 1, wx.EXPAND, 0)
        sizer_58.Add(self.text_ctrl_feeder_audit, 1, 0, 0)
        sizer_69.Add(sizer_58, 1, 0, 0)
        sizer_59.Add(self.text_ctrl_external_ref, 1, 0, 0)
        sizer_69.Add(sizer_59, 1, 0, 0)
        sizer_67.Add(sizer_69, 1, wx.EXPAND, 0)
        sizer_51.Add(sizer_67, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_51)
        sizer_51.Fit(self)
        # end wxGlade

# end of class PartyIdentified
class FeederAudit(wx.Panel):
    def __init__(self, *args, **kwds):
        # begin wxGlade: FeederAudit.__init__
        kwds["style"] = wx.TAB_TRAVERSAL
        wx.Panel.__init__(self, *args, **kwds)
        self.text_ctrl_originating_system_audit = wx.TextCtrl(self, -1, "")
        self.sizer_41_staticbox = wx.StaticBox(self, -1, _("originating_system_audit"))
        self.text_ctrl_feeder_system_audit = wx.TextCtrl(self, -1, "")
        self.sizer_43_staticbox = wx.StaticBox(self, -1, _("feeder_system_audit"))
        self.text_ctrl_original_content = wx.TextCtrl(self, -1, "")
        self.sizer_45_staticbox = wx.StaticBox(self, -1, _("original_content"))
        self.text_ctrl_originating_system_ids = wx.TextCtrl(self, -1, "")
        self.sizer_42_staticbox = wx.StaticBox(self, -1, _("originating_system_ids"))
        self.text_ctrl_feeder_system_ids = wx.TextCtrl(self, -1, "")
        self.sizer_44_staticbox = wx.StaticBox(self, -1, _("feeder_system_ids"))

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: FeederAudit.__set_properties
        pass
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: FeederAudit.__do_layout
        sizer_38 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_40 = wx.BoxSizer(wx.VERTICAL)
        self.sizer_44_staticbox.Lower()
        sizer_44 = wx.StaticBoxSizer(self.sizer_44_staticbox, wx.HORIZONTAL)
        self.sizer_42_staticbox.Lower()
        sizer_42 = wx.StaticBoxSizer(self.sizer_42_staticbox, wx.HORIZONTAL)
        sizer_39 = wx.BoxSizer(wx.VERTICAL)
        self.sizer_45_staticbox.Lower()
        sizer_45 = wx.StaticBoxSizer(self.sizer_45_staticbox, wx.HORIZONTAL)
        self.sizer_43_staticbox.Lower()
        sizer_43 = wx.StaticBoxSizer(self.sizer_43_staticbox, wx.HORIZONTAL)
        self.sizer_41_staticbox.Lower()
        sizer_41 = wx.StaticBoxSizer(self.sizer_41_staticbox, wx.HORIZONTAL)
        sizer_41.Add(self.text_ctrl_originating_system_audit, 1, 0, 0)
        sizer_39.Add(sizer_41, 1, wx.EXPAND, 0)
        sizer_39.Add((20, 20), 0, 0, 0)
        sizer_43.Add(self.text_ctrl_feeder_system_audit, 1, 0, 0)
        sizer_39.Add(sizer_43, 1, wx.EXPAND, 0)
        sizer_39.Add((20, 20), 0, 0, 0)
        sizer_45.Add(self.text_ctrl_original_content, 1, 0, 0)
        sizer_39.Add(sizer_45, 1, wx.EXPAND, 0)
        sizer_38.Add(sizer_39, 1, wx.EXPAND, 0)
        sizer_42.Add(self.text_ctrl_originating_system_ids, 1, 0, 0)
        sizer_40.Add(sizer_42, 1, wx.EXPAND, 0)
        sizer_40.Add((20, 20), 0, 0, 0)
        sizer_44.Add(self.text_ctrl_feeder_system_ids, 1, 0, 0)
        sizer_40.Add(sizer_44, 1, wx.EXPAND, 0)
        sizer_40.Add((20, 20), 0, 0, 0)
        sizer_40.Add((20, 20), 1, wx.EXPAND, 0)
        sizer_38.Add(sizer_40, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_38)
        sizer_38.Fit(self)
        # end wxGlade

# end of class FeederAudit

class Participation(wx.Panel):
    def __init__(self, *args, **kwds):
        # begin wxGlade: Participation.__init__
        kwds["style"] = wx.TAB_TRAVERSAL
        wx.Panel.__init__(self, *args, **kwds)
        self.text_ctrl_performer = wx.TextCtrl(self, -1, "")
        self.sizer_41_copy_staticbox = wx.StaticBox(self, -1, _("performer"))
        self.text_ctrl_mode = wx.TextCtrl(self, -1, "")
        self.sizer_43_copy_staticbox = wx.StaticBox(self, -1, _("mode"))
        self.text_ctrl_end_time = wx.TextCtrl(self, -1, "")
        self.sizer_45_copy_staticbox = wx.StaticBox(self, -1, _("end_time"))
        self.text_ctrl_function = wx.TextCtrl(self, -1, "")
        self.sizer_42_copy_staticbox = wx.StaticBox(self, -1, _("originating_function"))
        self.text_ctrl_start_time = wx.TextCtrl(self, -1, "")
        self.sizer_44_copy_staticbox = wx.StaticBox(self, -1, _("start_time"))

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: Participation.__set_properties
        pass
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: Participation.__do_layout
        sizer_38_copy = wx.BoxSizer(wx.HORIZONTAL)
        sizer_40_copy = wx.BoxSizer(wx.VERTICAL)
        self.sizer_44_copy_staticbox.Lower()
        sizer_44_copy = wx.StaticBoxSizer(self.sizer_44_copy_staticbox, wx.HORIZONTAL)
        self.sizer_42_copy_staticbox.Lower()
        sizer_42_copy = wx.StaticBoxSizer(self.sizer_42_copy_staticbox, wx.HORIZONTAL)
        sizer_39_copy = wx.BoxSizer(wx.VERTICAL)
        self.sizer_45_copy_staticbox.Lower()
        sizer_45_copy = wx.StaticBoxSizer(self.sizer_45_copy_staticbox, wx.HORIZONTAL)
        self.sizer_43_copy_staticbox.Lower()
        sizer_43_copy = wx.StaticBoxSizer(self.sizer_43_copy_staticbox, wx.HORIZONTAL)
        self.sizer_41_copy_staticbox.Lower()
        sizer_41_copy = wx.StaticBoxSizer(self.sizer_41_copy_staticbox, wx.HORIZONTAL)
        sizer_41_copy.Add(self.text_ctrl_performer, 1, 0, 0)
        sizer_39_copy.Add(sizer_41_copy, 1, wx.EXPAND, 0)
        sizer_39_copy.Add((20, 20), 0, 0, 0)
        sizer_43_copy.Add(self.text_ctrl_mode, 1, 0, 0)
        sizer_39_copy.Add(sizer_43_copy, 1, wx.EXPAND, 0)
        sizer_39_copy.Add((20, 20), 0, 0, 0)
        sizer_45_copy.Add(self.text_ctrl_end_time, 1, 0, 0)
        sizer_39_copy.Add(sizer_45_copy, 1, wx.EXPAND, 0)
        sizer_38_copy.Add(sizer_39_copy, 1, wx.EXPAND, 0)
        sizer_42_copy.Add(self.text_ctrl_function, 1, 0, 0)
        sizer_40_copy.Add(sizer_42_copy, 1, wx.EXPAND, 0)
        sizer_40_copy.Add((20, 20), 0, 0, 0)
        sizer_44_copy.Add(self.text_ctrl_start_time, 1, 0, 0)
        sizer_40_copy.Add(sizer_44_copy, 1, wx.EXPAND, 0)
        sizer_40_copy.Add((20, 20), 0, 0, 0)
        sizer_40_copy.Add((20, 20), 1, wx.EXPAND, 0)
        sizer_38_copy.Add(sizer_40_copy, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_38_copy)
        sizer_38_copy.Fit(self)
        # end wxGlade

# end of class Participation

class DvIdentifier(wx.Panel):
    def __init__(self, *args, **kwds):
        # begin wxGlade: DvIdentifier.__init__
        kwds["style"] = wx.TAB_TRAVERSAL
        wx.Panel.__init__(self, *args, **kwds)
        self.list_ctrl_identifier = EditableListControl(self, -1, style=wx.LC_REPORT | wx.SUNKEN_BORDER)
        self.sizer_64_copy_staticbox = wx.StaticBox(self, -1, "")
        self.button_add = wx.Button(self, -1, _("Add"))
        self.button_remove = wx.Button(self, -1, _("Remove"))
        self.text_ctrl_pattern = wx.TextCtrl(self, -1, "")
        self.sizer_25_copy_staticbox = wx.StaticBox(self, -1, _("pattern"))
        self.spin_ctrl_max_length = SpinCtrl(self, -1)
        self.sizer_26_copy_staticbox = wx.StaticBox(self, -1, _("max_length"))
        self.spin_ctrl_mix_length = SpinCtrl(self, -1)
        self.sizer_27_copy_staticbox = wx.StaticBox(self, -1, _("min_length"))
        self.sizer_23_copy_staticbox = wx.StaticBox(self, -1, _("coded_string"))
        self.text_ctrl_valid_time_begin = wx.TextCtrl(self, -1, "")
        self.sizer_52_staticbox = wx.StaticBox(self, -1, _("valid_time_begin"))
        self.text_ctrl_valid_time_end = wx.TextCtrl(self, -1, "")
        self.sizer_53_staticbox = wx.StaticBox(self, -1, _("valid_time_end"))
        self.radio_box_language = wx.RadioBox(self, -1, _("Selected?"), choices=[_("No"), _("Yes")], majorDimension=0, style=wx.RA_SPECIFY_ROWS)
        self.choice_language = wx.Choice(self, -1, choices=[])
        self.sizer_48_staticbox = wx.StaticBox(self, -1, _("language"))
        self.text_ctrl_data_name = wx.TextCtrl(self, -1, "")
        self.sizer_21_staticbox = wx.StaticBox(self, -1, _("data_name"))

        self.__set_properties()
        self.__do_layout()

        self.Bind(wx.EVT_BUTTON, self.evt_button_add_table, self.button_add)
        self.Bind(wx.EVT_BUTTON, self.evt_button_remove_table, self.button_remove)
        self.Bind(wx.EVT_RADIOBOX, self.evt_radiobox_language, self.radio_box_language)
        # end wxGlade
        
        self.init_things()

    def __set_properties(self):
        # begin wxGlade: DvIdentifier.__set_properties
        self.radio_box_language.SetSelection(0)
        self.choice_language.Enable(False)
        # end wxGlade


    def __do_layout(self):
        # begin wxGlade: DvIdentifier.__do_layout
        sizer_46 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_47 = wx.BoxSizer(wx.VERTICAL)
        sizer_13 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_21_staticbox.Lower()
        sizer_21 = wx.StaticBoxSizer(self.sizer_21_staticbox, wx.HORIZONTAL)
        self.sizer_48_staticbox.Lower()
        sizer_48 = wx.StaticBoxSizer(self.sizer_48_staticbox, wx.HORIZONTAL)
        sizer_49 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_53_staticbox.Lower()
        sizer_53 = wx.StaticBoxSizer(self.sizer_53_staticbox, wx.HORIZONTAL)
        self.sizer_52_staticbox.Lower()
        sizer_52 = wx.StaticBoxSizer(self.sizer_52_staticbox, wx.HORIZONTAL)
        self.sizer_23_copy_staticbox.Lower()
        sizer_23_copy = wx.StaticBoxSizer(self.sizer_23_copy_staticbox, wx.VERTICAL)
        sizer_50 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_27_copy_staticbox.Lower()
        sizer_27_copy = wx.StaticBoxSizer(self.sizer_27_copy_staticbox, wx.HORIZONTAL)
        self.sizer_26_copy_staticbox.Lower()
        sizer_26_copy = wx.StaticBoxSizer(self.sizer_26_copy_staticbox, wx.HORIZONTAL)
        self.sizer_25_copy_staticbox.Lower()
        sizer_25_copy = wx.StaticBoxSizer(self.sizer_25_copy_staticbox, wx.HORIZONTAL)
        sizer_62_copy = wx.BoxSizer(wx.VERTICAL)
        sizer_63_copy = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_64_copy_staticbox.Lower()
        sizer_64_copy = wx.StaticBoxSizer(self.sizer_64_copy_staticbox, wx.HORIZONTAL)
        sizer_64_copy.Add(self.list_ctrl_identifier, 1, wx.EXPAND, 0)
        sizer_62_copy.Add(sizer_64_copy, 1, wx.EXPAND, 0)
        sizer_63_copy.Add(self.button_add, 0, 0, 0)
        sizer_63_copy.Add((20, 20), 1, 0, 0)
        sizer_63_copy.Add(self.button_remove, 0, 0, 0)
        sizer_62_copy.Add(sizer_63_copy, 0, wx.EXPAND, 0)
        sizer_47.Add(sizer_62_copy, 1, wx.EXPAND, 0)
        sizer_25_copy.Add(self.text_ctrl_pattern, 1, wx.EXPAND, 0)
        sizer_50.Add(sizer_25_copy, 1, wx.EXPAND, 0)
        sizer_26_copy.Add(self.spin_ctrl_max_length, 1, wx.EXPAND, 0)
        sizer_50.Add(sizer_26_copy, 1, wx.EXPAND, 0)
        sizer_27_copy.Add(self.spin_ctrl_mix_length, 1, wx.EXPAND, 0)
        sizer_50.Add(sizer_27_copy, 1, wx.EXPAND, 0)
        sizer_23_copy.Add(sizer_50, 1, wx.EXPAND, 0)
        sizer_47.Add(sizer_23_copy, 0, wx.EXPAND, 0)
        sizer_52.Add(self.text_ctrl_valid_time_begin, 1, 0, 0)
        sizer_49.Add(sizer_52, 1, 0, 0)
        sizer_53.Add(self.text_ctrl_valid_time_end, 1, 0, 0)
        sizer_49.Add(sizer_53, 1, 0, 0)
        sizer_47.Add(sizer_49, 0, wx.EXPAND, 0)
        sizer_48.Add(self.radio_box_language, 0, 0, 0)
        sizer_48.Add((20, 20), 1, wx.EXPAND, 0)
        sizer_48.Add(self.choice_language, 0, 0, 0)
        sizer_13.Add(sizer_48, 0, 0, 0)
        sizer_21.Add(self.text_ctrl_data_name, 1, 0, 0)
        sizer_13.Add(sizer_21, 1, 0, 0)
        sizer_47.Add(sizer_13, 0, wx.EXPAND, 0)
        sizer_46.Add(sizer_47, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_46)
        sizer_46.Fit(self)
        # end wxGlade

    def init_things(self):
        self.init_list_crtl()
        self.set_lang()

    def set_lang(self):
        self.choice_language.SetItems(get_lang_list())
        self.choice_language.SetSelection(get_lang_list().index(info.language) | 0)

    def init_list_crtl(self):
        lista = self.list_ctrl_identifier
        lista.InsertColumn(0, 'issuer')
        lista.InsertColumn(1, 'assigner')
        lista.InsertColumn(2, 'id_name')
        lista.InsertColumn(3, 'coded_string')
        lista.SetColumnWidth(3, 100)


    def evt_button_ok(self):
        self.data_name_on_tree()

    def data_name_on_tree(self):
        name = self.text_ctrl_data_name.GetValue()
        if name:
            top_panel = self.GetTopLevelParent()
            tree = top_panel.tree_ctrl_ccd
            sel = tree.GetSelection()
            old_first_name = tree.GetItemText(sel).split(' ')[0]
            tree.SetItemText(sel, old_first_name + ' .' + name)


    def evt_radiobox_language(self, event):  # wxGlade: DvIdentifier.<event_handler>
        state = self.radio_box_language.GetSelection()

        if state:
            self.choice_language.Enable()
        else:
            self.choice_language.Disable()
            
    def evt_button_add_table(self, event):  # wxGlade: DvIdentifier.<event_handler>
        lista = self.list_ctrl_identifier
        index = lista.InsertStringItem(sys.maxint, 'issuer')
        lista.SetStringItem(index, 1, 'assigner')
        lista.SetStringItem(index, 2, 'id_name')
        lista.SetStringItem(index, 3, 'coded_string')


    def evt_button_remove_table(self, event):  # wxGlade: DvIdentifier.<event_handler>
        lista = self.list_ctrl_identifier
        count = lista.GetItemCount() - 1
        lista.DeleteItem(count)

# end of class DvIdentifier

class DvCodedString(wx.Panel):
    def __init__(self, *args, **kwds):
        # begin wxGlade: DvCodedString.__init__
        kwds["style"] = wx.TAB_TRAVERSAL
        wx.Panel.__init__(self, *args, **kwds)
        self.list_ctrl_terminology = EditableListControl(self, -1, style=wx.LC_REPORT | wx.SUNKEN_BORDER)
        self.sizer_64_staticbox = wx.StaticBox(self, -1, _("terminology"))
        self.button_add = wx.Button(self, -1, _("Add"))
        self.button_remove = wx.Button(self, -1, _("Remove"))
        self.text_ctrl_pattern = wx.TextCtrl(self, -1, "")
        self.sizer_25_copy_copy_staticbox = wx.StaticBox(self, -1, _("pattern"))
        self.spin_ctrl_max_length = SpinCtrl(self, -1)
        self.sizer_26_copy_copy_staticbox = wx.StaticBox(self, -1, _("max_length"))
        self.spin_ctrl_mix_length = SpinCtrl(self, -1)
        self.sizer_27_copy_copy_staticbox = wx.StaticBox(self, -1, _("min_length"))
        self.sizer_23_copy_1_staticbox = wx.StaticBox(self, -1, _("coded_string"))
        self.text_ctrl_valid_time_begin = wx.TextCtrl(self, -1, "")
        self.sizer_52_copy_staticbox = wx.StaticBox(self, -1, _("valid_time_begin"))
        self.text_ctrl_valid_time_end_copy_copy = wx.TextCtrl(self, -1, "")
        self.sizer_53_copy_staticbox = wx.StaticBox(self, -1, _("valid_time_end"))
        self.radio_box_language = wx.RadioBox(self, -1, _("Selected?"), choices=[_("No"), _("Yes")], majorDimension=0, style=wx.RA_SPECIFY_ROWS)
        self.choice_language = wx.Choice(self, -1, choices=[])
        self.sizer_48_copy_staticbox = wx.StaticBox(self, -1, _("language"))
        self.text_ctrl_data_name = wx.TextCtrl(self, -1, "")
        self.sizer_21_copy_staticbox = wx.StaticBox(self, -1, _("data_name"))

        self.__set_properties()
        self.__do_layout()

        self.Bind(wx.EVT_BUTTON, self.terminology_add, self.button_add)
        self.Bind(wx.EVT_BUTTON, self.terminology_remove, self.button_remove)
        self.Bind(wx.EVT_RADIOBOX, self.evt_radiobox_language, self.radio_box_language)
        # end wxGlade

        self.init_things()

    def __set_properties(self):
        # begin wxGlade: DvCodedString.__set_properties
        self.radio_box_language.SetSelection(0)
        self.choice_language.Enable(False)
        # end wxGlade


    def __do_layout(self):
        # begin wxGlade: DvCodedString.__do_layout
        sizer_54 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_55 = wx.BoxSizer(wx.VERTICAL)
        sizer_13_copy = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_21_copy_staticbox.Lower()
        sizer_21_copy = wx.StaticBoxSizer(self.sizer_21_copy_staticbox, wx.HORIZONTAL)
        self.sizer_48_copy_staticbox.Lower()
        sizer_48_copy = wx.StaticBoxSizer(self.sizer_48_copy_staticbox, wx.HORIZONTAL)
        sizer_49_copy = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_53_copy_staticbox.Lower()
        sizer_53_copy = wx.StaticBoxSizer(self.sizer_53_copy_staticbox, wx.HORIZONTAL)
        self.sizer_52_copy_staticbox.Lower()
        sizer_52_copy = wx.StaticBoxSizer(self.sizer_52_copy_staticbox, wx.HORIZONTAL)
        self.sizer_23_copy_1_staticbox.Lower()
        sizer_23_copy_1 = wx.StaticBoxSizer(self.sizer_23_copy_1_staticbox, wx.VERTICAL)
        sizer_50_copy = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_27_copy_copy_staticbox.Lower()
        sizer_27_copy_copy = wx.StaticBoxSizer(self.sizer_27_copy_copy_staticbox, wx.HORIZONTAL)
        self.sizer_26_copy_copy_staticbox.Lower()
        sizer_26_copy_copy = wx.StaticBoxSizer(self.sizer_26_copy_copy_staticbox, wx.HORIZONTAL)
        self.sizer_25_copy_copy_staticbox.Lower()
        sizer_25_copy_copy = wx.StaticBoxSizer(self.sizer_25_copy_copy_staticbox, wx.HORIZONTAL)
        sizer_62 = wx.BoxSizer(wx.VERTICAL)
        sizer_63 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_64_staticbox.Lower()
        sizer_64 = wx.StaticBoxSizer(self.sizer_64_staticbox, wx.HORIZONTAL)
        sizer_64.Add(self.list_ctrl_terminology, 1, wx.EXPAND, 0)
        sizer_62.Add(sizer_64, 1, wx.EXPAND, 0)
        sizer_63.Add(self.button_add, 0, 0, 0)
        sizer_63.Add((20, 20), 1, 0, 0)
        sizer_63.Add(self.button_remove, 0, 0, 0)
        sizer_62.Add(sizer_63, 0, wx.EXPAND, 0)
        sizer_55.Add(sizer_62, 1, wx.EXPAND, 0)
        sizer_25_copy_copy.Add(self.text_ctrl_pattern, 1, wx.EXPAND, 0)
        sizer_50_copy.Add(sizer_25_copy_copy, 1, wx.EXPAND, 0)
        sizer_26_copy_copy.Add(self.spin_ctrl_max_length, 1, wx.EXPAND, 0)
        sizer_50_copy.Add(sizer_26_copy_copy, 1, wx.EXPAND, 0)
        sizer_27_copy_copy.Add(self.spin_ctrl_mix_length, 1, wx.EXPAND, 0)
        sizer_50_copy.Add(sizer_27_copy_copy, 1, wx.EXPAND, 0)
        sizer_23_copy_1.Add(sizer_50_copy, 1, wx.EXPAND, 0)
        sizer_55.Add(sizer_23_copy_1, 0, wx.EXPAND, 0)
        sizer_52_copy.Add(self.text_ctrl_valid_time_begin, 1, 0, 0)
        sizer_49_copy.Add(sizer_52_copy, 1, 0, 0)
        sizer_53_copy.Add(self.text_ctrl_valid_time_end_copy_copy, 1, 0, 0)
        sizer_49_copy.Add(sizer_53_copy, 1, 0, 0)
        sizer_55.Add(sizer_49_copy, 0, wx.EXPAND, 0)
        sizer_48_copy.Add(self.radio_box_language, 0, 0, 0)
        sizer_48_copy.Add((20, 20), 1, wx.EXPAND, 0)
        sizer_48_copy.Add(self.choice_language, 0, 0, 0)
        sizer_13_copy.Add(sizer_48_copy, 0, 0, 0)
        sizer_21_copy.Add(self.text_ctrl_data_name, 1, 0, 0)
        sizer_13_copy.Add(sizer_21_copy, 1, 0, 0)
        sizer_55.Add(sizer_13_copy, 0, wx.EXPAND, 0)
        sizer_54.Add(sizer_55, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_54)
        sizer_54.Fit(self)
        # end wxGlade

    def init_things(self):
        self.init_list_crtl()
        self.set_lang()

    def set_lang(self):
        self.choice_language.SetItems(get_lang_list())
        self.choice_language.SetSelection(get_lang_list().index(info.language) | 0)
 
    def terminology_add(self, event):  # wxGlade: DvCodedString.<event_handler>
        index = self.list_ctrl_terminology.InsertStringItem(sys.maxint, 'code')
        self.list_ctrl_terminology.SetStringItem(index, 1, 'name')
        self.list_ctrl_terminology.SetStringItem(index, 2, 'abbrev')
        self.list_ctrl_terminology.SetStringItem(index, 3, 'version')
        self.list_ctrl_terminology.SetStringItem(index, 4, 'coded_string')

    def terminology_remove(self, event):  # wxGlade: DvCodedString.<event_handler>
        count = self.list_ctrl_terminology.GetItemCount() - 1
        self.list_ctrl_terminology.DeleteItem(count)

    def evt_button_ok(self):
        self.data_name_on_tree()

    def data_name_on_tree(self):
        name = self.text_ctrl_data_name.GetValue()
        if name:
            top_panel = self.GetTopLevelParent()
            tree = top_panel.tree_ctrl_ccd
            sel = tree.GetSelection()
            old_first_name = tree.GetItemText(sel).split(' ')[0]
            tree.SetItemText(sel, old_first_name + ' .' + name)


    def init_list_crtl(self):
        self.list_ctrl_terminology.InsertColumn(0, 'code')
        self.list_ctrl_terminology.InsertColumn(1, 'name')
        self.list_ctrl_terminology.InsertColumn(2, 'abbrev')
        self.list_ctrl_terminology.InsertColumn(3, 'version')
        self.list_ctrl_terminology.InsertColumn(4, 'coded_string')
        self.list_ctrl_terminology.SetColumnWidth(4, 100)


    def evt_radiobox_language(self, event):  # wxGlade: DvCodedString.<event_handler>
        state = self.radio_box_language.GetSelection()

        if state:
            self.choice_language.Enable()
        else:
            self.choice_language.Disable()
            
# end of class DvCodedString
class Attestation(wx.Panel):
    def __init__(self, *args, **kwds):
        # begin wxGlade: Attestation.__init__
        kwds["style"] = wx.TAB_TRAVERSAL
        wx.Panel.__init__(self, *args, **kwds)
        self.text_ctrl_attested_view = wx.TextCtrl(self, -1, "")
        self.sizer_31_staticbox = wx.StaticBox(self, -1, _("attested_view"))
        self.text_ctrl_proof = wx.TextCtrl(self, -1, "")
        self.sizer_32_staticbox = wx.StaticBox(self, -1, _("proof"))
        self.text_ctrl_reason = wx.TextCtrl(self, -1, "")
        self.sizer_33_staticbox = wx.StaticBox(self, -1, _("reason"))
        self.text_ctrl_is_pending = wx.TextCtrl(self, -1, "")
        self.sizer_34_staticbox = wx.StaticBox(self, -1, _("is_pending"))
        self.text_ctrl_commiter = wx.TextCtrl(self, -1, "")
        self.sizer_35_staticbox = wx.StaticBox(self, -1, _("commiter"))
        self.text_ctrl_time_commited = wx.TextCtrl(self, -1, "")
        self.sizer_36_staticbox = wx.StaticBox(self, -1, _("time_commited"))
        self.text_ctrl_feeder_audit = wx.TextCtrl(self, -1, "")
        self.sizer_37_staticbox = wx.StaticBox(self, -1, _("feeder_audit"))

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: Attestation.__set_properties
        pass
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: Attestation.__do_layout
        sizer_24 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_30 = wx.BoxSizer(wx.VERTICAL)
        self.sizer_37_staticbox.Lower()
        sizer_37 = wx.StaticBoxSizer(self.sizer_37_staticbox, wx.HORIZONTAL)
        self.sizer_36_staticbox.Lower()
        sizer_36 = wx.StaticBoxSizer(self.sizer_36_staticbox, wx.HORIZONTAL)
        self.sizer_35_staticbox.Lower()
        sizer_35 = wx.StaticBoxSizer(self.sizer_35_staticbox, wx.HORIZONTAL)
        sizer_29 = wx.BoxSizer(wx.VERTICAL)
        self.sizer_34_staticbox.Lower()
        sizer_34 = wx.StaticBoxSizer(self.sizer_34_staticbox, wx.HORIZONTAL)
        self.sizer_33_staticbox.Lower()
        sizer_33 = wx.StaticBoxSizer(self.sizer_33_staticbox, wx.HORIZONTAL)
        self.sizer_32_staticbox.Lower()
        sizer_32 = wx.StaticBoxSizer(self.sizer_32_staticbox, wx.HORIZONTAL)
        self.sizer_31_staticbox.Lower()
        sizer_31 = wx.StaticBoxSizer(self.sizer_31_staticbox, wx.HORIZONTAL)
        sizer_31.Add(self.text_ctrl_attested_view, 1, 0, 0)
        sizer_29.Add(sizer_31, 1, wx.EXPAND, 0)
        sizer_29.Add((20, 20), 0, 0, 0)
        sizer_32.Add(self.text_ctrl_proof, 1, 0, 0)
        sizer_29.Add(sizer_32, 1, wx.EXPAND, 0)
        sizer_29.Add((20, 20), 0, 0, 0)
        sizer_33.Add(self.text_ctrl_reason, 1, 0, 0)
        sizer_29.Add(sizer_33, 1, wx.EXPAND, 0)
        sizer_29.Add((20, 20), 0, 0, 0)
        sizer_34.Add(self.text_ctrl_is_pending, 1, 0, 0)
        sizer_29.Add(sizer_34, 1, wx.EXPAND, 0)
        sizer_24.Add(sizer_29, 1, wx.EXPAND, 0)
        sizer_35.Add(self.text_ctrl_commiter, 1, 0, 0)
        sizer_30.Add(sizer_35, 1, wx.EXPAND, 0)
        sizer_30.Add((20, 20), 0, 0, 0)
        sizer_36.Add(self.text_ctrl_time_commited, 1, 0, 0)
        sizer_30.Add(sizer_36, 1, wx.EXPAND, 0)
        sizer_30.Add((20, 20), 0, 0, 0)
        sizer_37.Add(self.text_ctrl_feeder_audit, 1, 0, 0)
        sizer_30.Add(sizer_37, 1, wx.EXPAND, 0)
        sizer_30.Add((20, 20), 0, 0, 0)
        sizer_30.Add((20, 20), 1, wx.EXPAND, 0)
        sizer_24.Add(sizer_30, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_24)
        sizer_24.Fit(self)
        # end wxGlade

# end of class Attestation
class DvURI(wx.Panel):
    def __init__(self, *args, **kwds):
        # begin wxGlade: DvURI.__init__
        kwds["style"] = wx.TAB_TRAVERSAL
        wx.Panel.__init__(self, *args, **kwds)
        self.text_ctrl_data_name = wx.TextCtrl(self, -1, "")
        self.sizer_10_staticbox = wx.StaticBox(self, -1, _("data_name"))
        self.text_ctrl_vtime_begin = wx.TextCtrl(self, -1, "")
        self.sizer_14_staticbox = wx.StaticBox(self, -1, _("valid_time_begin"))
        self.text_ctrl_vtime_end = wx.TextCtrl(self, -1, "")
        self.sizer_18_staticbox = wx.StaticBox(self, -1, _("valid_time_end"))
        self.editable_list_box_enumeration = EditableListBox(self, -1, _("Values"))
        self.sizer_28_staticbox = wx.StaticBox(self, -1, _("enumeration"))
        self.text_ctrl_pattern = wx.TextCtrl(self, -1, "")
        self.sizer_25_staticbox = wx.StaticBox(self, -1, _("pattern"))
        self.text_ctrl_max_length = wx.TextCtrl(self, -1, "")
        self.sizer_26_staticbox = wx.StaticBox(self, -1, _("max_length"))
        self.text_ctrl_min_length = wx.TextCtrl(self, -1, "")
        self.sizer_27_staticbox = wx.StaticBox(self, -1, _("min_length"))
        self.sizer_23_staticbox = wx.StaticBox(self, -1, _("dv"))

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

        self.init_things()

    def __set_properties(self):
        # begin wxGlade: DvURI.__set_properties
        pass
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: DvURI.__do_layout
        sizer_3 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_23_staticbox.Lower()
        sizer_23 = wx.StaticBoxSizer(self.sizer_23_staticbox, wx.VERTICAL)
        self.sizer_27_staticbox.Lower()
        sizer_27 = wx.StaticBoxSizer(self.sizer_27_staticbox, wx.HORIZONTAL)
        self.sizer_26_staticbox.Lower()
        sizer_26 = wx.StaticBoxSizer(self.sizer_26_staticbox, wx.HORIZONTAL)
        self.sizer_25_staticbox.Lower()
        sizer_25 = wx.StaticBoxSizer(self.sizer_25_staticbox, wx.HORIZONTAL)
        self.sizer_28_staticbox.Lower()
        sizer_28 = wx.StaticBoxSizer(self.sizer_28_staticbox, wx.VERTICAL)
        sizer_7 = wx.BoxSizer(wx.VERTICAL)
        self.sizer_18_staticbox.Lower()
        sizer_18 = wx.StaticBoxSizer(self.sizer_18_staticbox, wx.HORIZONTAL)
        self.sizer_14_staticbox.Lower()
        sizer_14 = wx.StaticBoxSizer(self.sizer_14_staticbox, wx.HORIZONTAL)
        self.sizer_10_staticbox.Lower()
        sizer_10 = wx.StaticBoxSizer(self.sizer_10_staticbox, wx.HORIZONTAL)
        sizer_10.Add(self.text_ctrl_data_name, 1, 0, 0)
        sizer_7.Add(sizer_10, 1, wx.EXPAND, 0)
        sizer_7.Add((20, 20), 0, 0, 0)
        sizer_14.Add(self.text_ctrl_vtime_begin, 1, 0, 0)
        sizer_7.Add(sizer_14, 1, wx.EXPAND, 0)
        sizer_7.Add((20, 20), 0, 0, 0)
        sizer_18.Add(self.text_ctrl_vtime_end, 1, 0, 0)
        sizer_7.Add(sizer_18, 1, wx.EXPAND, 0)
        sizer_3.Add(sizer_7, 1, wx.EXPAND, 0)
        sizer_28.Add(self.editable_list_box_enumeration, 1, wx.EXPAND, 0)
        sizer_23.Add(sizer_28, 1, wx.EXPAND, 0)
        sizer_25.Add(self.text_ctrl_pattern, 1, wx.EXPAND, 0)
        sizer_23.Add(sizer_25, 0, wx.EXPAND, 0)
        sizer_26.Add(self.text_ctrl_max_length, 1, wx.EXPAND, 0)
        sizer_23.Add(sizer_26, 0, wx.EXPAND, 0)
        sizer_27.Add(self.text_ctrl_min_length, 1, wx.EXPAND, 0)
        sizer_23.Add(sizer_27, 0, wx.EXPAND, 0)
        sizer_3.Add(sizer_23, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_3)
        sizer_3.Fit(self)
        # end wxGlade

    def init_things(self):
        pass

    def evt_button_ok(self):
        self.data_name_on_tree()

    def data_name_on_tree(self):
        name = self.text_ctrl_data_name.GetValue()
        if name:
            top_panel = self.GetTopLevelParent()
            tree = top_panel.tree_ctrl_ccd
            sel = tree.GetSelection()
            old_first_name = tree.GetItemText(sel).split(' ')[0]
            tree.SetItemText(sel, old_first_name + ' .' + name)



# end of class DvURI

class Cluster(wx.Panel):
    def __init__(self, *args, **kwds):
        # begin wxGlade: Cluster.__init__
        kwds["style"] = wx.TAB_TRAVERSAL
        wx.Panel.__init__(self, *args, **kwds)
        self.radio_btn_cluster = wx.RadioButton(self, -1, _("Cluster   "))
        self.text_ctrl_cluster = wx.TextCtrl(self, -1, "")
        self.radio_btn_element = wx.RadioButton(self, -1, _("Element"))
        self.radio_btn_slot = wx.RadioButton(self, -1, _("Slot"))

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: Cluster.__set_properties
        self.text_ctrl_cluster.SetMinSize((100, 27))
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: Cluster.__do_layout
        sizer_12 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_70 = wx.BoxSizer(wx.VERTICAL)
        sizer_71 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_71.Add(self.radio_btn_cluster, 0, 0, 0)
        sizer_71.Add(self.text_ctrl_cluster, 0, 0, 0)
        sizer_70.Add(sizer_71, 0, wx.EXPAND, 0)
        sizer_70.Add(self.radio_btn_element, 0, 0, 0)
        sizer_70.Add(self.radio_btn_slot, 0, 0, 0)
        sizer_12.Add(sizer_70, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_12)
        sizer_12.Fit(self)
        # end wxGlade

    def evt_button_ok(self):
        top_panel = self.GetTopLevelParent()
        tree = top_panel.tree_ctrl_ccd
        item = tree.GetSelection()

        parent = self.GetParent()
        grandparent = self.GetGrandParent()

        subject = None
        if self.radio_btn_cluster.GetValue():
            sel_string = 'Cluster'
            subject = self.text_ctrl_cluster.GetValue()
        elif self.radio_btn_element.GetValue():
            sel_string = 'Element'
        elif self.radio_btn_slot.GetValue():
            sel_string = 'Slot'

        if subject:
            sel_string += ' .' + subject

        tree.AppendItem(item, sel_string)
        tree.Expand(item)


# end of class Cluster

class ClusterEmbed(Cluster):
    def __init__(self, *args, **kwds):
        self.suffix = kwds.pop('suffix', '')

        Cluster.__init__(self, *args, **kwds)
        self.Bind(wx.EVT_RADIOBUTTON, self.evt_radio_button)

    def evt_radio_button(self, event):

        top_panel = self.GetTopLevelParent()
        tree = top_panel.tree_ctrl_ccd
        tree_selected = tree.GetSelection()

        subject = None
        if self.radio_btn_cluster.GetValue():
            sel_string = 'Cluster'
            subject = self.text_ctrl_cluster.GetValue()
        elif self.radio_btn_element.GetValue():
            sel_string = 'Element'
        elif self.radio_btn_slot.GetValue():
            sel_string = 'Slot'

        if subject:
            sel_string += ' .' + subject

        sel_string += self.suffix

        child, cookie = tree.GetFirstChild(tree_selected)
        while child.IsOk():
            txt = tree.GetItemText(child)
            if txt.endswith(self.suffix):
                tree.InsertItem(tree_selected, child, sel_string)
                tree.Delete(child)
                return

            child, cookie = tree.GetNextChild(tree_selected, cookie)



        tree.AppendItem(tree_selected, sel_string)
        tree.Expand(tree_selected)

    # Undefining parent function
    def evt_button_ok(self):
        pass

class Element(wx.Panel):
    def __init__(self, *args, **kwds):
        # begin wxGlade: Element.__init__
        kwds["style"] = wx.TAB_TRAVERSAL
        wx.Panel.__init__(self, *args, **kwds)
        self.choice_element = wx.Choice(self, -1, choices=[_("DvBoolean"), _("DvURI"), _("DvString"), _("DvCodedString"), _("DvIdentifier"), _("DvParsable"), _("DvMedia"), _("DvOrdinal"), _("DvCount"), _("DvRatio"), _("DvRate"), _("DvProportion"), _("DvInterval"), _("DvQuantity"), _("DvTime"), _("DvDate"), _("DvDateTime"), _("DvDuration"), _("DvDay"), _("DvMonth"), _("DvYear"), _("DvYearMonth"), _("DvMonthDay")])
        self.sizer_8_staticbox = wx.StaticBox(self, -1, _("Select the Element:"))

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: Element.__set_properties
        self.choice_element.SetSelection(0)
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: Element.__do_layout
        sizer_11 = wx.BoxSizer(wx.VERTICAL)
        self.sizer_8_staticbox.Lower()
        sizer_8 = wx.StaticBoxSizer(self.sizer_8_staticbox, wx.VERTICAL)
        sizer_8.Add(self.choice_element, 0, 0, 0)
        sizer_11.Add(sizer_8, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_11)
        sizer_11.Fit(self)
        # end wxGlade

    def evt_button_ok(self):
        grandparent = self.GetGrandParent()

        sel_string = self.choice_element.GetStringSelection()
        tree = grandparent.tree_ctrl_ccd
        tree_selected = tree.GetSelection()

        # Tests if there is some other element already
        if tree.GetChildrenCount(tree_selected):
            dlg = wx.MessageDialog(self, 'Would you like to substitute this element?', 'Element', wx.YES_NO | wx.ICON_QUESTION)

            result = dlg.ShowModal()
            if result == wx.ID_YES:
                tree.DeleteChildren(tree_selected)
            else:
                return

        tree.AppendItem(tree_selected, sel_string)
        tree.Expand(tree_selected)


# end of class Element
class Definition(wx.Panel):
    def __init__(self, *args, **kwds):
        # begin wxGlade: Definition.__init__
        kwds["style"] = wx.TAB_TRAVERSAL
        wx.Panel.__init__(self, *args, **kwds)
        self.radio_box_definition = wx.RadioBox(self, -1, _("Select the type of the CCD:"), choices=[_("CareEntry"), _("AdminEntry"), _("DemographicEntry"), _("Cluster"), _("Element"), _("Slot")], majorDimension=0, style=wx.RA_SPECIFY_ROWS)

        self.__set_properties()
        self.__do_layout()
        # end wxGlade


    def __set_properties(self):
        # begin wxGlade: Definition.__set_properties
        self.radio_box_definition.SetSelection(0)
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: Definition.__do_layout
        sizer_5 = wx.BoxSizer(wx.VERTICAL)
        sizer_5.Add(self.radio_box_definition, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_5)
        sizer_5.Fit(self)
        # end wxGlade

    def evt_button_ok(self):
        grandparent = self.GetGrandParent()

        sel_string = self.radio_box_definition.GetStringSelection()
        tree = grandparent.tree_ctrl_ccd

        tree_selected = tree.GetSelection()

        # Tests if there is something at the tree
        if tree.GetChildrenCount(tree_selected):
            dlg = wx.MessageDialog(self, 'Would you like to start over the CCD?', 'CCD', wx.YES_NO | wx.ICON_QUESTION)

            result = dlg.ShowModal()
            if result == wx.ID_YES:
                tree.DeleteChildren(tree_selected)
            else:
                return

        tree.AppendItem(tree_selected, sel_string)
        tree.Expand(tree_selected)

# end of class Definition

class CareEntry(wx.Panel):
    def __init__(self, *args, **kwds):
        # begin wxGlade: CareEntry.__init__
        kwds["style"] = wx.TAB_TRAVERSAL
        wx.Panel.__init__(self, *args, **kwds)
        self.notebook_care_entry = wx.Notebook(self, -1, style=0)
        self.panel_care_entry = wx.Panel(self.notebook_care_entry, -1)
        self.panel_data = wx.Panel(self.panel_care_entry, -1)
        self.sizer_72_staticbox = wx.StaticBox(self.panel_care_entry, -1, _("Data"))
        self.panel_provider = wx.Panel(self.panel_care_entry, -1)
        self.sizer_73_staticbox = wx.StaticBox(self.panel_care_entry, -1, _("Provider"))
        self.radio_box_subject = wx.RadioBox(self.panel_care_entry, -1, _("Subject"), choices=[_("PartySelf"), _("PartyIdentified")], majorDimension=0, style=wx.RA_SPECIFY_ROWS)
        self.button_links = wx.Button(self.panel_care_entry, -1, _("Links"))
        self.button_attestation = wx.Button(self.panel_care_entry, -1, _("Attestation"))
        self.button_feeder_audit = wx.Button(self.panel_care_entry, -1, _("Feeder Audit"))
        self.radio_box_language = wx.RadioBox(self.panel_care_entry, -1, _("Selected?"), choices=[_("No"), _("Yes")], majorDimension=0, style=wx.RA_SPECIFY_ROWS)
        self.choice_language = wx.Choice(self.panel_care_entry, -1, choices=[])
        self.sizer_48_staticbox = wx.StaticBox(self.panel_care_entry, -1, _("language"))
        self.button_protocol_id = wx.Button(self.panel_care_entry, -1, _("Protocol Id"))
        self.button_other_participants = wx.Button(self.panel_care_entry, -1, _("Other Participants"))
        self.button_encoding = wx.Button(self.panel_care_entry, -1, _("Encoding"))
        self.button_workflow_id = wx.Button(self.panel_care_entry, -1, _("Workflow Id"))

        self.__set_properties()
        self.__do_layout()

        self.Bind(wx.EVT_RADIOBOX, self.evt_radiobox_subject, self.radio_box_subject)
        self.Bind(wx.EVT_BUTTON, self.evt_button_links, self.button_links)
        self.Bind(wx.EVT_BUTTON, self.evt_button_attestation, self.button_attestation)
        self.Bind(wx.EVT_BUTTON, self.evt_button_feeder_audit, self.button_feeder_audit)
        self.Bind(wx.EVT_RADIOBOX, self.evt_radiobox_language, self.radio_box_language)
        self.Bind(wx.EVT_BUTTON, self.evt_button_protocol_id, self.button_protocol_id)
        self.Bind(wx.EVT_BUTTON, self.evt_button_other_participants, self.button_other_participants)
        self.Bind(wx.EVT_BUTTON, self.evt_button_enconding, self.button_encoding)
        self.Bind(wx.EVT_BUTTON, self.evt_button_workflow_id, self.button_workflow_id)
        # end wxGlade

        self.init_things()

    def __set_properties(self):
        # begin wxGlade: CareEntry.__set_properties
        self.radio_box_subject.SetSelection(0)
        self.radio_box_language.SetSelection(0)
        self.choice_language.Enable(False)
        self.notebook_care_entry.SetBackgroundColour(wx.Colour(176, 0, 255))
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: CareEntry.__do_layout
        sizer_17 = wx.BoxSizer(wx.VERTICAL)
        sizer_4 = wx.BoxSizer(wx.VERTICAL)
        sizer_20 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_19 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_48_staticbox.Lower()
        sizer_48 = wx.StaticBoxSizer(self.sizer_48_staticbox, wx.HORIZONTAL)
        sizer_6 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_73_staticbox.Lower()
        sizer_73 = wx.StaticBoxSizer(self.sizer_73_staticbox, wx.HORIZONTAL)
        self.sizer_72_staticbox.Lower()
        sizer_72 = wx.StaticBoxSizer(self.sizer_72_staticbox, wx.HORIZONTAL)
        sizer_6.Add((20, 20), 0, wx.EXPAND, 0)
        sizer_72.Add(self.panel_data, 1, wx.EXPAND, 0)
        sizer_6.Add(sizer_72, 1, wx.EXPAND, 0)
        sizer_6.Add((20, 20), 0, wx.EXPAND, 0)
        sizer_73.Add(self.panel_provider, 1, wx.EXPAND, 0)
        sizer_6.Add(sizer_73, 1, wx.EXPAND, 0)
        sizer_6.Add((20, 20), 0, wx.EXPAND, 0)
        sizer_6.Add(self.radio_box_subject, 1, wx.EXPAND, 0)
        sizer_6.Add((20, 20), 0, wx.EXPAND, 0)
        sizer_4.Add(sizer_6, 1, wx.EXPAND, 0)
        sizer_19.Add((20, 20), 0, wx.EXPAND, 0)
        sizer_19.Add(self.button_links, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_19.Add((20, 20), 1, wx.EXPAND, 0)
        sizer_19.Add(self.button_attestation, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_19.Add((20, 20), 1, wx.EXPAND, 0)
        sizer_19.Add(self.button_feeder_audit, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_19.Add((20, 20), 1, wx.EXPAND, 0)
        sizer_48.Add(self.radio_box_language, 0, 0, 0)
        sizer_48.Add((20, 20), 1, wx.EXPAND, 0)
        sizer_48.Add(self.choice_language, 0, 0, 0)
        sizer_19.Add(sizer_48, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_19.Add((20, 20), 0, wx.EXPAND, 0)
        sizer_4.Add(sizer_19, 1, wx.EXPAND, 0)
        sizer_20.Add((20, 20), 0, wx.EXPAND, 0)
        sizer_20.Add(self.button_protocol_id, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_20.Add((20, 20), 1, wx.EXPAND, 0)
        sizer_20.Add(self.button_other_participants, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_20.Add((20, 20), 1, wx.EXPAND, 0)
        sizer_20.Add(self.button_encoding, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_20.Add((20, 20), 1, wx.EXPAND, 0)
        sizer_20.Add(self.button_workflow_id, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_20.Add((20, 20), 0, wx.EXPAND, 0)
        sizer_4.Add(sizer_20, 1, wx.EXPAND, 0)
        self.panel_care_entry.SetSizer(sizer_4)
        self.notebook_care_entry.AddPage(self.panel_care_entry, _("CareEntry"))
        sizer_17.Add(self.notebook_care_entry, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_17)
        sizer_17.Fit(self)
        # end wxGlade

    def init_things(self):
        self.init_panels()
        self.set_lang()

    def set_lang(self):
        self.choice_language.SetItems(get_lang_list())
        self.choice_language.SetSelection(get_lang_list().index(info.language) | 0)

    def init_panels(self):
        self.data = ClusterEmbed(self.panel_data, suffix=' - Data')
        self.provider = ClusterEmbed(self.panel_provider, suffix=' - Provider')


    def populate_main_tree(self):

        top_panel = self.GetTopLevelParent()
        tree = top_panel.tree_ctrl_ccd
        item = tree.GetSelection()

        if tree.GetChildrenCount(item) >= 3:
            pass
        else:
        
            self.tree_data = tree.AppendItem(item, 'data')
            self.tree_provider = tree.AppendItem(item, 'provider')
            self.tree_subject = tree.AppendItem(item, 'subject')
        
            tree.Expand(item)

    def evt_button_remove(self):
        tab_number = self.notebook_care_entry.GetSelection()
        if tab_number:
            self.notebook_care_entry.DeletePage(tab_number)
        else:
            top_panel = self.GetTopLevelParent()
            tree = top_panel.tree_ctrl_ccd
            item = tree.GetSelection()
            tree.Delete(item)

    def evt_button_ok(self):
        pass

    def evt_button_links(self, event):  # wxGlade: CareEntry.<event_handler>
        "Opens another tab with a DvURI panel on it"

        tab = DvURI(self.notebook_care_entry)
        self.notebook_care_entry.AddPage(tab, 'Links')


    def evt_button_attestation(self, event):  # wxGlade: CareEntry.<event_handler>
        "Opens another tab with a Attestation panel on it"

        tab = Attestation(self.notebook_care_entry)
        self.notebook_care_entry.AddPage(tab, 'Attestation')

    def evt_button_feeder_audit(self, event):  # wxGlade: CareEntry.<event_handler>
        "Opens another tab with a FeederAudit panel on it"

        tab = FeederAudit(self.notebook_care_entry)
        self.notebook_care_entry.AddPage(tab, 'FeederAudit')

    def evt_button_other_participants(self, event):  # wxGlade: CareEntry.<event_handler>
        "Opens another tab with a Participation panel on it"

        tab = Participation(self.notebook_care_entry)
        self.notebook_care_entry.AddPage(tab, 'OtherParticipants')


    def evt_button_enconding(self, event):  # wxGlade: CareEntry.<event_handler>
        "Opens another tab with a DvCodedString panel on it"

        tab = DvCodedString(self.notebook_care_entry)
        self.notebook_care_entry.AddPage(tab, 'Encoding')


    def evt_button_protocol_id(self, event):  # wxGlade: CareEntry.<event_handler>
        "Opens another tab with a DvIdentifier panel on it"

        tab = DvIdentifier(self.notebook_care_entry)
        self.notebook_care_entry.AddPage(tab, 'ProtocolId')


    def evt_button_workflow_id(self, event):  # wxGlade: CareEntry.<event_handler>
        "Opens another tab with a DvURI panel on it"

        tab = DvURI(self.notebook_care_entry)
        self.notebook_care_entry.AddPage(tab, 'WorkflowId')

    def evt_radiobox_data(self, event):  # wxGlade: CareEntry.<event_handler>

        top_panel = self.GetTopLevelParent()
        tree = top_panel.tree_ctrl_ccd
        tree_selected = tree.GetSelection()

        sel_string = self.radio_box_data.GetStringSelection() + ' - Data'

        child, cookie = tree.GetFirstChild(tree_selected)
        while child.IsOk():
            txt = tree.GetItemText(child)
            if txt.endswith('Data'):
                tree.InsertItem(tree_selected, child, sel_string)
                tree.Delete(child)
                return

            child, cookie = tree.GetNextChild(tree_selected, cookie)

        tree.AppendItem(tree_selected, sel_string)
        tree.Expand(tree_selected)

    def evt_radio_box_provider(self, event):  # wxGlade: CareEntry.<event_handler>
        top_panel = self.GetTopLevelParent()
        tree = top_panel.tree_ctrl_ccd
        tree_selected = tree.GetSelection()

        sel_string = self.radio_box_provider.GetStringSelection() + ' - Provider'
        child, cookie = tree.GetFirstChild(tree_selected)
        while child.IsOk():
            txt = tree.GetItemText(child)
            if txt.endswith('Provider'):
                tree.InsertItem(tree_selected, child, sel_string)
                tree.Delete(child)
                return

            child, cookie = tree.GetNextChild(tree_selected, cookie)



        tree.AppendItem(tree_selected, sel_string)
        tree.Expand(tree_selected)

    def evt_radiobox_subject(self, event):  # wxGlade: CareEntry.<event_handler>
        top_panel = self.GetTopLevelParent()
        tree = top_panel.tree_ctrl_ccd
        tree_selected = tree.GetSelection()

        sel_string = self.radio_box_subject.GetStringSelection() + ' - Subject'
        child, cookie = tree.GetFirstChild(tree_selected)
        while child.IsOk():
            txt = tree.GetItemText(child)
            if txt.endswith('Subject'):
                tree.InsertItem(tree_selected, child, sel_string)
                tree.Delete(child)
                return

            child, cookie = tree.GetNextChild(tree_selected, cookie)



        tree.AppendItem(tree_selected, sel_string)
        tree.Expand(tree_selected)

    def evt_radiobox_language(self, event):  # wxGlade: CareEntry.<event_handler>
        state = self.radio_box_language.GetSelection()

        if state:
            self.choice_language.Enable()
        else:
            self.choice_language.Disable()
            
# end of class CareEntry

class EditableListControl(wx.ListCtrl,
                   listmix.ListCtrlAutoWidthMixin,
                   listmix.TextEditMixin):

    def __init__(self, parent, ID, pos=wx.DefaultPosition,
                 size=wx.DefaultSize, style=0):
        wx.ListCtrl.__init__(self, parent, ID, pos, size, style)

        listmix.ListCtrlAutoWidthMixin.__init__(self)
        listmix.TextEditMixin.__init__(self)


class UnderConstruction(wx.Panel):
    def __init__(self, *args, **kwds):
        # begin wxGlade: UnderConstruction.__init__
        kwds["style"] = wx.TAB_TRAVERSAL
        wx.Panel.__init__(self, *args, **kwds)
        self.label_construction = wx.StaticText(self, -1, _("Under construction!"))
        self.bitmap_construction = wx.StaticBitmap(self, -1, wx.Bitmap("under-construction-1.png", wx.BITMAP_TYPE_ANY))

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: UnderConstruction.__set_properties
        self.label_construction.SetFont(wx.Font(18, wx.TELETYPE, wx.NORMAL, wx.NORMAL, 0, "Arial Black"))
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: UnderConstruction.__do_layout
        sizer_15 = wx.BoxSizer(wx.VERTICAL)
        sizer_15.Add(self.label_construction, 0, wx.ALIGN_CENTER_HORIZONTAL, 0)
        sizer_15.Add((20, 20), 0, 0, 0)
        sizer_15.Add(self.bitmap_construction, 0, wx.ALIGN_CENTER_HORIZONTAL, 0)
        self.SetSizer(sizer_15)
        sizer_15.Fit(self)
        # end wxGlade

# end of class UnderConstruction

class MyPanel4(wx.Panel):
    def __init__(self, *args, **kwds):
        # begin wxGlade: MyPanel4.__init__
        kwds["style"] = wx.TAB_TRAVERSAL
        wx.Panel.__init__(self, *args, **kwds)
        self.radio_btn_care_entry = wx.RadioButton(self, -1, _("CareEntry"))
        self.radio_btn_admin_entry = wx.RadioButton(self, -1, _("AdminEntry"))
        self.radio_btn_demographic_entry = wx.RadioButton(self, -1, _("DemographicEntry"))
        self.radio_btn_cluster = wx.RadioButton(self, -1, _("Cluster"))
        self.radio_btn_element = wx.RadioButton(self, -1, _("Element"))
        self.sizer_22_staticbox = wx.StaticBox(self, -1, _("Select the type of the CCD:"))
        self.radio_box_language_copy = wx.RadioBox(self, -1, _("Selected?"), choices=[_("No"), _("Yes")], majorDimension=0, style=wx.RA_SPECIFY_ROWS)
        self.choice_language_copy = wx.Choice(self, -1, choices=[])
        self.sizer_48_copy_copy_staticbox = wx.StaticBox(self, -1, _("language"))

        self.__set_properties()
        self.__do_layout()

        self.Bind(wx.EVT_RADIOBOX, self.evt_radiobox_language, self.radio_box_language_copy)
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: MyPanel4.__set_properties
        self.radio_btn_care_entry.SetForegroundColour(wx.Colour(127, 0, 255))
        self.radio_btn_cluster.SetForegroundColour(wx.Colour(255, 127, 0))
        self.radio_btn_element.SetForegroundColour(wx.Colour(255, 127, 0))
        self.radio_box_language_copy.SetSelection(0)
        self.choice_language_copy.Enable(False)
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: MyPanel4.__do_layout
        sizer_16 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_48_copy_copy_staticbox.Lower()
        sizer_48_copy_copy = wx.StaticBoxSizer(self.sizer_48_copy_copy_staticbox, wx.HORIZONTAL)
        self.sizer_22_staticbox.Lower()
        sizer_22 = wx.StaticBoxSizer(self.sizer_22_staticbox, wx.VERTICAL)
        sizer_22.Add(self.radio_btn_care_entry, 0, 0, 0)
        sizer_22.Add(self.radio_btn_admin_entry, 0, 0, 0)
        sizer_22.Add(self.radio_btn_demographic_entry, 0, 0, 0)
        sizer_22.Add(self.radio_btn_cluster, 0, 0, 0)
        sizer_22.Add(self.radio_btn_element, 0, 0, 0)
        sizer_16.Add(sizer_22, 1, wx.EXPAND, 0)
        sizer_48_copy_copy.Add(self.radio_box_language_copy, 0, 0, 0)
        sizer_48_copy_copy.Add((20, 20), 1, wx.EXPAND, 0)
        sizer_48_copy_copy.Add(self.choice_language_copy, 0, 0, 0)
        sizer_16.Add(sizer_48_copy_copy, 0, 0, 0)
        self.SetSizer(sizer_16)
        sizer_16.Fit(self)
        # end wxGlade

    def evt_radiobox_language(self, event):  # wxGlade: MyPanel4.<event_handler>
        print "Event handler `evt_radiobox_language' not implemented"
        event.Skip()

# end of class MyPanel4
class ConfigDialog(wx.Dialog):
    def __init__(self, *args, **kwds):
        # begin wxGlade: ConfigDialog.__init__
        kwds["style"] = wx.DEFAULT_DIALOG_STYLE
        wx.Dialog.__init__(self, *args, **kwds)
        self.text_ctrl_workspace = wx.TextCtrl(self, -1, "")
        self.sizer_9_staticbox = wx.StaticBox(self, -1, _("Workspace path:"))
        self.text_ctrl_autosave = wx.TextCtrl(self, -1, "")
        self.sizer_12_staticbox = wx.StaticBox(self, -1, _("Autosave:"))
        self.button_2 = wx.Button(self, wx.ID_CANCEL, "")
        self.button_1 = wx.Button(self, wx.ID_OK, "")

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: ConfigDialog.__set_properties
        self.SetTitle(_("Configuration"))
        self.SetSize((629, 205))
        self.text_ctrl_autosave.SetMinSize((70, 27))
        self.text_ctrl_autosave.SetToolTipString(_("Put the interval in minutes that the current CDD will be automatically saved."))
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: ConfigDialog.__do_layout
        sizer_13 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_14 = wx.BoxSizer(wx.VERTICAL)
        sizer_main = wx.BoxSizer(wx.VERTICAL)
        sizer_10 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_11 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_12_staticbox.Lower()
        sizer_12 = wx.StaticBoxSizer(self.sizer_12_staticbox, wx.HORIZONTAL)
        sizer_2 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_9_staticbox.Lower()
        sizer_9 = wx.StaticBoxSizer(self.sizer_9_staticbox, wx.HORIZONTAL)
        sizer_13.Add((20, 20), 0, 0, 0)
        sizer_14.Add((20, 20), 0, 0, 0)
        sizer_9.Add(self.text_ctrl_workspace, 1, 0, 0)
        sizer_2.Add(sizer_9, 1, wx.EXPAND, 7)
        sizer_main.Add(sizer_2, 1, wx.EXPAND, 0)
        sizer_12.Add(self.text_ctrl_autosave, 0, 0, 0)
        sizer_11.Add(sizer_12, 0, wx.EXPAND, 0)
        sizer_11.Add((20, 20), 1, wx.EXPAND, 0)
        sizer_main.Add(sizer_11, 1, wx.EXPAND, 0)
        sizer_10.Add((20, 20), 1, 0, 0)
        sizer_10.Add(self.button_2, 0, wx.BOTTOM | wx.ALIGN_BOTTOM, 0)
        sizer_10.Add((20, 20), 0, 0, 0)
        sizer_10.Add(self.button_1, 0, wx.BOTTOM | wx.ALIGN_BOTTOM, 0)
        sizer_main.Add(sizer_10, 1, wx.EXPAND, 0)
        sizer_14.Add(sizer_main, 1, wx.EXPAND, 0)
        sizer_14.Add((20, 20), 0, 0, 0)
        sizer_13.Add(sizer_14, 1, wx.EXPAND, 0)
        sizer_13.Add((20, 20), 0, 0, 0)
        self.SetSizer(sizer_13)
        self.Layout()
        # end wxGlade

# end of class ConfigDialog

class MetadataPanel(wx.Panel):
    def __init__(self, *args, **kwds):
        # begin wxGlade: MetadataPanel.__init__
        kwds["style"] = wx.TAB_TRAVERSAL
        wx.Panel.__init__(self, *args, **kwds)
        self.label_title = wx.StaticText(self, -1, _("* Title:  "), style=wx.ALIGN_CENTRE)
        self.text_ctrl_title = wx.TextCtrl(self, -1, "")
        self.label_date = wx.StaticText(self, -1, _("Date :"))
        self.datepicker_ctrl_date = wx.DatePickerCtrl(self, -1)
        self.label_description = wx.StaticText(self, -1, _("* Description:  "))
        self.text_ctrl_description = wx.TextCtrl(self, -1, "", style=wx.TE_MULTILINE)
        self.label_language = wx.StaticText(self, -1, _("Language:  "))
        self.choice_lang = wx.Choice(self, -1, choices=[])
        self.label_subject = wx.StaticText(self, -1, _("* Subject:  "))
        self.text_ctrl_subject = wx.TextCtrl(self, -1, "")
        self.label_creator = wx.StaticText(self, -1, _("* Creator name:  "))
        self.text_ctrl_creator = wx.TextCtrl(self, -1, "")
        self.label_creator_email = wx.StaticText(self, -1, _("Creator email:  "))
        self.text_ctrl_creator_email = wx.TextCtrl(self, -1, "")
        self.label_source = wx.StaticText(self, -1, _("Source:  "))
        self.text_ctrl_source = wx.TextCtrl(self, -1, "")
        self.label_rights = wx.StaticText(self, -1, _("* Rights:  "))
        self.text_ctrl_rights = wx.TextCtrl(self, -1, "")
        self.label_publisher = wx.StaticText(self, -1, _("Publisher:  "))
        self.text_ctrl_publisher = wx.TextCtrl(self, -1, "")
        self.label_relation = wx.StaticText(self, -1, _("Relation:  "))
        self.text_ctrl_relation = wx.TextCtrl(self, -1, "")
        self.label_coverage = wx.StaticText(self, -1, _("Coverage:  "))
        self.text_ctrl_coverage = wx.TextCtrl(self, -1, "")
        self.label_contributors = wx.StaticText(self, -1, _("Contributors:  "))
        self.text_ctrl_contributors = wx.TextCtrl(self, -1, "")
        self.button_ok = wx.Button(self, wx.ID_SAVE, "")

        self.__set_properties()
        self.__do_layout()

        self.Bind(wx.EVT_TEXT, self.enable_ok, self.text_ctrl_title)
        self.Bind(wx.EVT_TEXT, self.enable_ok, self.text_ctrl_description)
        self.Bind(wx.EVT_CHOICE, self.enable_ok, self.choice_lang)
        self.Bind(wx.EVT_TEXT, self.enable_ok, self.text_ctrl_subject)
        self.Bind(wx.EVT_TEXT, self.enable_ok, self.text_ctrl_creator)
        self.Bind(wx.EVT_TEXT, self.enable_ok, self.text_ctrl_creator_email)
        self.Bind(wx.EVT_TEXT, self.enable_ok, self.text_ctrl_source)
        self.Bind(wx.EVT_TEXT, self.enable_ok, self.text_ctrl_rights)
        self.Bind(wx.EVT_TEXT, self.enable_ok, self.text_ctrl_publisher)
        self.Bind(wx.EVT_TEXT, self.enable_ok, self.text_ctrl_relation)
        self.Bind(wx.EVT_TEXT, self.enable_ok, self.text_ctrl_coverage)
        self.Bind(wx.EVT_TEXT, self.enable_ok, self.text_ctrl_contributors)
        self.Bind(wx.EVT_BUTTON, self.save_config, self.button_ok)
        # end wxGlade

        self.init_things()

    def __set_properties(self):
        # begin wxGlade: MetadataPanel.__set_properties
        self.SetSize((683, 583))
        self.label_date.SetToolTipString(_("Defalts to current day."))
        self.datepicker_ctrl_date.SetMinSize((111, 28))
        self.choice_lang.SetItems(get_lang_list())
        self.choice_lang.SetSelection(get_lang_list().index('en-US') | 0)
        self.text_ctrl_subject.SetToolTipString(_("Format emails as: Timothy W. Cook <timothywayne.cook@gmail.com>"))
        self.label_creator.SetToolTipString(_("Format emails as: Timothy W. Cook <timothywayne.cook@gmail.com>"))
        self.text_ctrl_creator.SetToolTipString(_("Format emails as: Timothy W. Cook <timothywayne.cook@gmail.com>"))
        self.text_ctrl_publisher.SetToolTipString(_("Format emails as: Timothy W. Cook <timothywayne.cook@gmail.com>"))
        self.label_contributors.SetToolTipString(_("Separate multiple contributors with a semi-colon and format them as:Eduardo Cesar <xcesar@gmail.com>; Luciana Cavalini <lutricav@vm.uff.br>"))
        self.text_ctrl_contributors.SetToolTipString(_("Separate multiple contributors with a semi-colon and format them as:Eduardo Cesar <xcesar@gmail.com>; Luciana Cavalini <lutricav@vm.uff.br>"))
        self.button_ok.Enable(False)
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: MetadataPanel.__do_layout
        sizer_vertical = wx.BoxSizer(wx.HORIZONTAL)
        sizer_3 = wx.BoxSizer(wx.VERTICAL)
        sizer_2_copy = wx.BoxSizer(wx.HORIZONTAL)
        sizer_1 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_8 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_7 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_6_copy = wx.BoxSizer(wx.HORIZONTAL)
        sizer_6 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_5 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_4 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_vertical.Add((20, 20), 0, 0, 0)
        sizer_4.Add(self.label_title, 0, wx.ALIGN_CENTER_VERTICAL, 1)
        sizer_4.Add(self.text_ctrl_title, 1, wx.ALIGN_CENTER_VERTICAL, 1)
        sizer_4.Add((20, 20), 0, 0, 0)
        sizer_4.Add(self.label_date, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_4.Add(self.datepicker_ctrl_date, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_3.Add(sizer_4, 1, wx.ALL | wx.EXPAND, 1)
        sizer_5.Add(self.label_description, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_5.Add(self.text_ctrl_description, 1, wx.EXPAND | wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_5.Add((20, 20), 0, 0, 0)
        sizer_5.Add(self.label_language, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_5.Add(self.choice_lang, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_3.Add(sizer_5, 1, wx.EXPAND, 0)
        sizer_6.Add(self.label_subject, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_6.Add(self.text_ctrl_subject, 1, wx.ALIGN_CENTER_VERTICAL, 1)
        sizer_3.Add(sizer_6, 1, wx.EXPAND, 0)
        sizer_6_copy.Add(self.label_creator, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_6_copy.Add(self.text_ctrl_creator, 1, wx.ALIGN_CENTER_VERTICAL, 1)
        sizer_6_copy.Add((20, 20), 0, 0, 0)
        sizer_6_copy.Add(self.label_creator_email, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_6_copy.Add(self.text_ctrl_creator_email, 1, wx.ALIGN_CENTER_VERTICAL, 1)
        sizer_6_copy.Add((20, 20), 0, 0, 0)
        sizer_3.Add(sizer_6_copy, 1, wx.EXPAND, 0)
        sizer_7.Add(self.label_source, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_7.Add(self.text_ctrl_source, 1, wx.ALIGN_CENTER_VERTICAL, 1)
        sizer_7.Add((20, 20), 0, 0, 0)
        sizer_7.Add(self.label_rights, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_7.Add(self.text_ctrl_rights, 1, wx.ALIGN_CENTER_VERTICAL, 1)
        sizer_7.Add((20, 20), 0, 0, 0)
        sizer_7.Add(self.label_publisher, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_7.Add(self.text_ctrl_publisher, 1, wx.ALIGN_CENTER_VERTICAL, 1)
        sizer_3.Add(sizer_7, 1, wx.EXPAND, 0)
        sizer_8.Add(self.label_relation, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_8.Add(self.text_ctrl_relation, 1, wx.ALIGN_CENTER_VERTICAL, 1)
        sizer_8.Add((20, 20), 0, 0, 0)
        sizer_8.Add(self.label_coverage, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_8.Add(self.text_ctrl_coverage, 1, wx.ALIGN_CENTER_VERTICAL, 1)
        sizer_3.Add(sizer_8, 1, wx.EXPAND, 0)
        sizer_1.Add(self.label_contributors, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_1.Add(self.text_ctrl_contributors, 1, wx.ALIGN_CENTER_VERTICAL, 1)
        sizer_3.Add(sizer_1, 1, wx.EXPAND, 0)
        sizer_2_copy.Add((20, 20), 1, wx.EXPAND, 1)
        sizer_2_copy.Add(self.button_ok, 0, wx.ALIGN_BOTTOM, 0)
        sizer_3.Add(sizer_2_copy, 1, wx.EXPAND, 0)
        sizer_vertical.Add(sizer_3, 1, wx.EXPAND, 0)
        sizer_vertical.Add((20, 20), 0, 0, 0)
        self.SetSizer(sizer_vertical)
        # end wxGlade

    def init_things(self):
        self.info = None
        self.init_config()
        self.read_config()
        self.button_ok.Disable()

    def init_config(self):
        if sys.platform.startswith('linux'):
            home = os.environ['HOME']
        elif sys.platform.startswith('win'):
            home = os.environ['HOMEDRIVE'] + '/' +os.environ['HOMEPATH']

        else:
            home = './'
        self.configdir = home + '/.mlhim'
        self.configname = self.configdir + '/' + 'metadata.cfg'

        self.config = ConfigParser.SafeConfigParser({
                'title' : '',
                'description' : '',
                'creator' : '',
                'creator_email' : '',
                'contributor' : '',
                'publisher' : '',
                'subject' : '',
                'source' : '',
                'rights' : 'CC-BY http://creativecommons.org/licenses/by/3.0/',
                'relation' : 'None',
                'coverage' : 'Universal',
                'language' : '76',
                'choice_definition' : '0',
                })

        if not os.path.isdir(self.configdir):
            try:
                os.mkdir(self.configdir)
            except:
                popup_message(None, 'Config directory NOT created.', 'Error creating config dir', wx.ICON_EXCLAMATION)


    def read_config(self):
        self.config.read(self.configname)
        self.set_panel_configs()

    def save_config(self, event=None):   # wxGlade: MetadataPanel.<event_handler>
        self.get_panel_configs()
        try:
            with open(self.configname, 'wb') as configfile:
                configfile.write('# Concept Definition Designer Configuration\n# Do not edit the text to the left of the equal symbol (=)\n\n')
                self.config.write(configfile)
        except IOError:
            popup_message(None, 'Config could not be saved.', 'Error saving config', wx.ICON_EXCLAMATION)

        self.set_meta_info()
        self.button_ok.Disable()

    def set_meta_info(self):
        # Sets the necessary information to the info object
        if self.info:
            title = self.text_ctrl_title.GetValue().encode('utf8')
            description = self.text_ctrl_description.GetValue().encode('utf8')
            creator = self.text_ctrl_creator.GetValue().encode('utf8')
            creator_email = self.text_ctrl_creator_email.GetValue().encode('utf8')
            contributor = self.text_ctrl_contributors.GetValue().encode('utf8')

            publisher = self.text_ctrl_publisher.GetValue().encode('utf8')
            subject = self.text_ctrl_subject.GetValue().encode('utf8')
            source = self.text_ctrl_source.GetValue().encode('utf8')
            rights = self.text_ctrl_rights.GetValue().encode('utf8')
            relation = self.text_ctrl_relation.GetValue().encode('utf8')
            coverage = self.text_ctrl_coverage.GetValue().encode('utf8')

            language = self.choice_lang.GetStringSelection()

            tempo = self.datepicker_ctrl_date.GetValue()
            date = '{Y}-{M:02}-{D:02}'.format(Y=tempo.GetYear(), M=tempo.GetMonth()+1, D=tempo.GetDay())

            self.info.get_info(title, description, date, creator, creator_email, contributor, language, publisher, subject, source, rights, relation, coverage)

    def get_panel_configs(self):
        self.config.set('DEFAULT', 'title', self.text_ctrl_title.GetValue().encode('utf8'))
        self.config.set('DEFAULT', 'description', self.text_ctrl_description.GetValue().encode('utf8'))
        self.config.set('DEFAULT', 'creator', self.text_ctrl_creator.GetValue().encode('utf8'))
        self.config.set('DEFAULT', 'creator_email', self.text_ctrl_creator_email.GetValue().encode('utf8'))
        self.config.set('DEFAULT', 'contributor', self.text_ctrl_contributors.GetValue().encode('utf8'))

        self.config.set('DEFAULT', 'publisher', self.text_ctrl_publisher.GetValue().encode('utf8'))
        self.config.set('DEFAULT', 'subject', self.text_ctrl_subject.GetValue().encode('utf8'))
        self.config.set('DEFAULT', 'source', self.text_ctrl_source.GetValue().encode('utf8'))
        self.config.set('DEFAULT', 'rights', self.text_ctrl_rights.GetValue().encode('utf8'))
        self.config.set('DEFAULT', 'relation', self.text_ctrl_relation.GetValue().encode('utf8'))
        self.config.set('DEFAULT', 'coverage', self.text_ctrl_coverage.GetValue().encode('utf8'))

        self.config.set('DEFAULT', 'language', str(self.choice_lang.GetSelection()))

    def set_panel_configs(self):
        self.text_ctrl_title.SetValue(self.config.get('DEFAULT', 'title'))
        self.text_ctrl_description.SetValue(self.config.get('DEFAULT', 'description'))
        self.text_ctrl_creator.SetValue(self.config.get('DEFAULT', 'creator'))
        self.text_ctrl_creator_email.SetValue(self.config.get('DEFAULT', 'creator_email'))
        self.text_ctrl_contributors.SetValue(self.config.get('DEFAULT', 'contributor'))

        self.text_ctrl_publisher.SetValue(self.config.get('DEFAULT', 'publisher'))
        self.text_ctrl_subject.SetValue(self.config.get('DEFAULT', 'subject'))
        self.text_ctrl_source.SetValue(self.config.get('DEFAULT', 'source'))
        self.text_ctrl_rights.SetValue(self.config.get('DEFAULT', 'rights'))
        self.text_ctrl_relation.SetValue(self.config.get('DEFAULT', 'relation'))
        self.text_ctrl_coverage.SetValue(self.config.get('DEFAULT', 'coverage'))

        self.choice_lang.SetSelection(int(self.config.get('DEFAULT', 'language')))

    def enable_ok(self, event):  # wxGlade: MetadataPanel.<event_handler>
        self.button_ok.Enable()

# end of class MetadataPanel

class MainFrame(wx.Frame):
    def __init__(self, *args, **kwds):
        # begin wxGlade: MainFrame.__init__
        kwds["style"] = wx.DEFAULT_FRAME_STYLE
        wx.Frame.__init__(self, *args, **kwds)
        
        # Menu Bar
        self.frame_main_menubar = wx.MenuBar()
        wxglade_tmp_menu = wx.Menu()
        wxglade_tmp_menu.Append(20, _("&New\tCtrl-N"), "", wx.ITEM_NORMAL)
        wxglade_tmp_menu.Append(30, _("&Open\tCtrl-O"), "", wx.ITEM_NORMAL)
        wxglade_tmp_menu.Append(40, _("&Save\tCtrl-S"), "", wx.ITEM_NORMAL)
        wxglade_tmp_menu.Append(50, _("Save &As"), "", wx.ITEM_NORMAL)
        wxglade_tmp_menu_sub = wx.Menu()
        wxglade_tmp_menu_sub.Append(200, _("XML Schema"), "", wx.ITEM_NORMAL)
        wxglade_tmp_menu_sub.Append(210, _("XForm"), "", wx.ITEM_NORMAL)
        wxglade_tmp_menu.AppendMenu(70, _("&Export"), wxglade_tmp_menu_sub, "")
        wxglade_tmp_menu.Append(60, _("&Validate\tCtrl-L"), "", wx.ITEM_NORMAL)
        wxglade_tmp_menu.Append(80, _("&Quit\tCtrl-W"), "", wx.ITEM_NORMAL)
        self.frame_main_menubar.Append(wxglade_tmp_menu, _("&File"))
        wxglade_tmp_menu = wx.Menu()
        wxglade_tmp_menu.Append(100, _("&Undo\tCtrl-Z"), "", wx.ITEM_NORMAL)
        wxglade_tmp_menu.Append(110, _("&Redo\tCtrl-Y"), "", wx.ITEM_NORMAL)
        self.frame_main_menubar.Append(wxglade_tmp_menu, _("&Edit"))
        wxglade_tmp_menu = wx.Menu()
        wxglade_tmp_menu.Append(130, _("&New"), "", wx.ITEM_NORMAL)
        self.frame_main_menubar.Append(wxglade_tmp_menu, _("&Project"))
        wxglade_tmp_menu = wx.Menu()
        wxglade_tmp_menu.Append(150, _("&Options"), "", wx.ITEM_NORMAL)
        wxglade_tmp_menu.Append(160, _("&Save"), "", wx.ITEM_NORMAL)
        self.frame_main_menubar.Append(wxglade_tmp_menu, _("&Config"))
        wxglade_tmp_menu = wx.Menu()
        wxglade_tmp_menu.Append(180, _("&Users Guide\tCtrl-H"), "", wx.ITEM_NORMAL)
        wxglade_tmp_menu.Append(190, _("&About"), "", wx.ITEM_NORMAL)
        self.frame_main_menubar.Append(wxglade_tmp_menu, _("&Help"))
        self.SetMenuBar(self.frame_main_menubar)
        # Menu Bar end
        self.frame_main_statusbar = self.CreateStatusBar(1, 0)
        self.tree_ctrl_ccd = wx.TreeCtrl(self, -1, style=wx.TR_HAS_BUTTONS | wx.TR_NO_LINES | wx.TR_DEFAULT_STYLE | wx.SUNKEN_BORDER)
        self.panel_top_right = wx.Panel(self, -1)
        self.button_remove = wx.Button(self, -1, _("Remove"))
        self.button_ok = wx.Button(self, wx.ID_OK, "")

        self.__set_properties()
        self.__do_layout()

        self.Bind(wx.EVT_MENU, self.file_new, id=20)
        self.Bind(wx.EVT_MENU, self.file_open, id=30)
        self.Bind(wx.EVT_MENU, self.file_save, id=40)
        self.Bind(wx.EVT_MENU, self.file_save_as, id=50)
        self.Bind(wx.EVT_MENU, self.export_xsd, id=200)
        self.Bind(wx.EVT_MENU, self.export_xform, id=210)
        self.Bind(wx.EVT_MENU, self.file_validate, id=60)
        self.Bind(wx.EVT_MENU, self.file_quit, id=80)
        self.Bind(wx.EVT_MENU, self.project_new, id=130)
        self.Bind(wx.EVT_MENU, self.config_options, id=150)
        self.Bind(wx.EVT_MENU, self.config_save, id=160)
        self.Bind(wx.EVT_MENU, self.help_users_guide, id=180)
        self.Bind(wx.EVT_MENU, self.help_about, id=190)
        self.Bind(wx.EVT_TREE_DELETE_ITEM, self.evt_tree_delete_item, self.tree_ctrl_ccd)
        self.Bind(wx.EVT_TREE_ITEM_ACTIVATED, self.evt_tree_item_activated, self.tree_ctrl_ccd)
        self.Bind(wx.EVT_TREE_SEL_CHANGED, self.evt_tree_sel_changed, self.tree_ctrl_ccd)
        self.Bind(wx.EVT_BUTTON, self.evt_button_remove, self.button_remove)
        self.Bind(wx.EVT_BUTTON, self.evt_button_ok, self.button_ok)
        # end wxGlade
        #self.Bind(wx.EVT_TREE_ITEM_RIGHT_CLICK, self.evt_tree_item_right_click, self.tree_ctrl_ccd)

        self.init_things()

    def __set_properties(self):
        # begin wxGlade: MainFrame.__set_properties
        self.SetTitle(_("Constraint Definition Designer (aka CCD Editor)"))
        self.SetSize((900, 600))
        self.frame_main_statusbar.SetStatusWidths([-1])
        # statusbar fields
        frame_main_statusbar_fields = [_("CDD Editor")]
        for i in range(len(frame_main_statusbar_fields)):
            self.frame_main_statusbar.SetStatusText(frame_main_statusbar_fields[i], i)
        self.tree_ctrl_ccd.SetBackgroundColour(wx.Colour(252, 231, 36))
        self.button_remove.Hide()
        self.button_ok.Hide()
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: MainFrame.__do_layout
        sizer_main = wx.BoxSizer(wx.VERTICAL)
        sizer_1 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_2 = wx.BoxSizer(wx.VERTICAL)
        sizer_18_copy = wx.BoxSizer(wx.HORIZONTAL)
        sizer_1.Add(self.tree_ctrl_ccd, 1, wx.EXPAND, 0)
        sizer_2.Add(self.panel_top_right, 1, wx.EXPAND, 0)
        sizer_18_copy.Add((20, 20), 1, wx.EXPAND, 0)
        sizer_18_copy.Add(self.button_remove, 0, wx.ALIGN_BOTTOM, 0)
        sizer_18_copy.Add((20, 20), 0, 0, 0)
        sizer_18_copy.Add(self.button_ok, 0, wx.ALIGN_BOTTOM, 0)
        sizer_2.Add(sizer_18_copy, 0, wx.EXPAND, 0)
        sizer_1.Add(sizer_2, 3, wx.EXPAND, 0)
        sizer_main.Add(sizer_1, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_main)
        self.Layout()
        # end wxGlade

    def init_things(self):
        self.setup_tree()
        self.setup_metadata()
        self.button_ok.Hide()

    def setup_metadata(self):
        # Hack to make the metadata panel before it is called
        # We need to make it before to be able to get the info from it
        # at the program start
        self.dummy_panel = wx.Panel(self.panel_top_right, -1)
        self.dummy_panel.Hide()
        self.metadata = MetadataPanel(self.dummy_panel)
        self.metadata.info = info
        self.metadata.set_meta_info()


    def setup_tree(self):
        self.root = self.tree_ctrl_ccd.AddRoot('CCD')
        self.metadata = self.tree_ctrl_ccd.AppendItem(self.root, "Metadata")
        self.definition = self.tree_ctrl_ccd.AppendItem(self.root, "definition")
        self.tree_ctrl_ccd.ExpandAll()

        
    def evt_button_remove(self, event):  # wxGlade: MainFrame.<event_handler>
        try:
            panel, = self.panel_top_right.GetChildren()
        except ValueError:
            return

        try:
            panel.evt_button_remove
        except AttributeError:
            item = self.tree_ctrl_ccd.GetSelection()
            self.tree_ctrl_ccd.Delete(item)
            return
        
        panel.evt_button_remove()

    def evt_button_ok(self, event):  # wxGlade: MainFrame.<event_handler>
        try:
            panel, = self.panel_top_right.GetChildren()
        except ValueError:
            return

        try:
            panel.evt_button_ok
        except AttributeError:
            return
        
        panel.evt_button_ok()

    def evt_tree_item_activated(self, event):  # wxGlade: MainFrame.<event_handler>
        pass

    # def evt_tree_item_right_click(self, event):  # wxGlade: MainFrame.<event_handler>
    #     item =  event.GetItem()
    #     self.tree_ctrl_ccd.Delete(item)

    def evt_tree_sel_changed(self, event):  # wxGlade: MainFrame.<event_handler>

        # Clear the top right panel
        c = self.panel_top_right.GetChildren()
        if c:
            for i in c:
                i.Destroy()

        item =  event.GetItem()
        selTextRaw = self.tree_ctrl_ccd.GetItemText(item)

        selText = selTextRaw.split(' ')[0].strip()

        self.button_ok.Show()
        self.button_remove.Show()
        self.Layout()


        if selText == "CCD":

            self.button_ok.Hide()
            self.button_remove.Hide()
            self.Layout()
            choice = UnderConstruction(self.panel_top_right)


        elif selText == "Metadata":

            self.button_ok.Hide()
            self.button_remove.Hide()
            self.Layout()
            choice = MetadataPanel(self.panel_top_right)

            # Necessary for exporting the metadata
            choice.info = info


        elif selText == "definition":
            #self.display.SetLabel("definition selected.")
            if self.button_remove.Shown:
                self.button_remove.Hide()
                self.Layout()

            choice = Definition(self.panel_top_right)

        elif selText == "Cluster":
            choice = Cluster(self.panel_top_right)

        elif selText == "Slot":
            choice = Slot(self.panel_top_right)

        elif selText == "CareEntry":
            choice = CareEntry(self.panel_top_right)

        elif selText == "AdminEntry":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DemographicEntry":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "Element":
            choice = Element(self.panel_top_right)

        elif selText == "DvBoolean":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvURI":
            choice = DvURI(self.panel_top_right)

        elif selText == "DvString":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvCodedString":
            choice = DvCodedString(self.panel_top_right)

        elif selText == "DvIdentifier":
            choice = DvIdentifier(self.panel_top_right)

        elif selText == "DvParsable":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvMedia":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvOrdinal":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvCount":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvRatio":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvRate":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvProportion":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvInterval":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvQuantity":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvTime":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvDate":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvDateTime":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvDuration":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvDay":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvMonth":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvYear":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvYearMonth":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "DvMonthDay":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "ReferenceRange":
            choice = UnderConstruction(self.panel_top_right)

        elif selText == "PartySelf":
            choice = PartySelf(self.panel_top_right)

        elif selText == "PartyIdentified":
            choice = PartyIdentified(self.panel_top_right)

        elif selText == "Attestation":
            choice = Attestation(self.panel_top_right)

        elif selText == "Participation":
            choice = Participation(self.panel_top_right)

        elif selText == "FeederAudit":
            choice = FeederAudit(self.panel_top_right)

        elif selText == "FeederAuditDetails":
            choice = UnderConstruction(self.panel_top_right)

        if 'choice' in locals():
            choice.SetClientSize(choice.GetParent().GetSize())


    def evt_tree_delete_item(self, event):  # wxGlade: MainFrame.<event_handler>
        pass
    def file_new(self, event):  # wxGlade: MainFrame.<event_handler>
        print "Event handler `file_new' not implemented"
        event.Skip()

    def file_open(self, event):  # wxGlade: MainFrame.<event_handler>
        print "Event handler `file_open' not implemented"
        event.Skip()

    def file_save(self, event):  # wxGlade: MainFrame.<event_handler>
        print "Event handler `file_save' not implemented"
        event.Skip()

    def file_save_as(self, event):  # wxGlade: MainFrame.<event_handler>
        print "Event handler `file_save_as' not implemented"
        event.Skip()

    def file_validate(self, event):  # wxGlade: MainFrame.<event_handler>
        print "Event handler `file_validate' not implemented"
        event.Skip()

    def file_quit(self, event):  # wxGlade: MainFrame.<event_handler>
        print "Event handler `file_quit' not implemented"
        event.Skip()

    def project_new(self, event):  # wxGlade: MainFrame.<event_handler>
        print "Event handler `project_new' not implemented"
        event.Skip()

    def config_options(self, event):  # wxGlade: MainFrame.<event_handler>
        print "Event handler `config_options' not implemented"
        event.Skip()

    def config_save(self, event):  # wxGlade: MainFrame.<event_handler>
        print "Event handler `config_save' not implemented"
        event.Skip()

    def help_users_guide(self, event):  # wxGlade: MainFrame.<event_handler>
        print "Event handler `help_users_guide' not implemented"
        event.Skip()

    def help_about(self, event):  # wxGlade: MainFrame.<event_handler>
        # First we create and fill the info object
        about = wx.AboutDialogInfo()
        about.Name = "CDD (aka. CCD Editor)"
        #about.Version = cdd_version.VERSION
        about.Copyright = "(C) 2012 Timothy W. Cook"
        about.Description = wordwrap(
            _("Used for creating and editing constraint definitions for the MLHIM project."),
            350, wx.ClientDC(self))
        about.WebSite = ("http://www.mlhim.org", "MLHIM " + _("Main site."))
        about.Developers = credits

        about.License = wordwrap(licenseText, 500, wx.ClientDC(self))

        # Then we call wx.AboutBox giving it that info object
        wx.AboutBox(about)


    def export_xsd(self, event):  # wxGlade: MainFrame.<event_handler>
        # Get the path
        path = get_path(self)
        if not path:
            return
        info.randomize_uuid()
        info.generate_file(path)
        # Show dialog
        popup_message(self, '%s.xsd' % info.ccd_id, _('Generated the file'), wx.OK | wx.ICON_INFORMATION)

    def export_xform(self, event):  # wxGlade: MainFrame.<event_handler>
        print "Event handler `export_xform' not implemented"
        event.Skip()

# end of class MainFrame

# This class holds the XSD file that will be created.
class Info(object):
    def __init__(self):
        self.title = ''
        self.description = ''
        self.creator = ''
        self.creator_email = ''
        self.contributor = ''

        self.publisher = ''
        self.subject = ''
        self.source = ''
        self.rights = ''
        self.relation = ''
        self.coverage = ''

        self.language = ''

        self.date = ''

        self.ccd_id = "ccd_"+str(uuid.uuid4()).replace('-','_')

    def get_info(self, title, description, date, creator, creator_email, contributor, language, publisher, subject, source, rights, relation, coverage):
        self.title = title
        self.description = description
        self.creator = creator
        self.creator_email = creator_email
        self.contributor = contributor

        self.publisher = publisher
        self.subject = subject
        self.source = source
        self.rights = rights
        self.relation = relation
        self.coverage = coverage

        self.language = language

        self.date = date


    def generate_file(self, path):


        UUID_definition = "ct_"+str(uuid.uuid4()).replace('-','_')
        UUID_string = "ct_"+str(uuid.uuid4()).replace('-','_')
        UUID_complex = "ct_"+str(uuid.uuid4()).replace('-','_')

        schema = self.ccd_id + ".xsd"

        contributors_formated = '<dc:contributor>' + \
            '</dc:contributor>\n<dc:contributor>'.join([ escape(i).strip() for i in self.contributor.split(';')]) + \
            '</dc:contributor>'

        f = open(path+'/'+schema,'w')

        f.write("""<?xml version="1.0" encoding="UTF-8"?>

<xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema"
	   xmlns:mlhim2="http://www.mlhim.org/xmls/mlhim2/2_3_1" 
	   elementFormDefault="qualified"
	   targetNamespace="http://www.mlhim.org/xmls/mlhim2/2_3_1"
	   xmlns:data-view="http://www.w3.org/2003/g/data-view#" 
	   data-view:transformation="http://www.mlhim.org/ccd/ccd_md_view.xsl">

  <xs:annotation>
    <xs:appinfo source="http://www.mlhim.org" xml:lang="{language}">
      This is a {title} Concept Constraint Definition schema file (CCD).

      <rdf:RDF
	  xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:dc= "http://purl.org/dc/elements/1.1/">

	<rdf:Description rdf:about="http://www.mlhim.org/ccd/{ccd_id}">
	  <dc:title>{title}</dc:title>
	  <dc:creator>{creator} &lt;{creator_email}&gt; </dc:creator>
          {contributors}
          <dc:subject>{subject}</dc:subject>
	  <dc:source>{source}</dc:source>
	  <dc:rights>{rights}</dc:rights>
	  <dc:relation>{relation}</dc:relation>
	  <dc:coverage>{coverage}</dc:coverage>
	  <dc:type>{resource_type}</dc:type>
	  <dc:identifier>{identifier}</dc:identifier>
	  <dc:description>{description}</dc:description>
	  <dc:publisher>{publisher}</dc:publisher>
	  <dc:date>{date}</dc:date>
	  <dc:format>{resource_format}</dc:format>
	  <dc:language>{language}</dc:language>
	</rdf:Description>

	</rdf:RDF>

    </xs:appinfo>
  </xs:annotation>

  <xs:include schemaLocation="http://www.mlhim.org/xmls/mlhim2/2_3_1/mlhim2.xsd"/>

  <xs:element name="{ccd_id}" type="mlhim2:{UUID_complex}"/>
  <xs:complexType name="{UUID_complex}">
    <xs:complexContent>
    <xs:restriction base="mlhim2:CCDType">
	<xs:sequence>
	  <xs:element name="definition"  minOccurs="1"  maxOccurs="1" type="mlhim2:{UUID_definition}"/>
	</xs:sequence>
    </xs:restriction>
    </xs:complexContent>
  </xs:complexType>

</xs:schema>
""".format(ccd_id = self.ccd_id,
           UUID_definition = UUID_definition,
           UUID_DvString = UUID_string,
           UUID_complex = UUID_complex,

           title = escape(self.title),
           description = escape(self.description),
           date = self.date,
           creator = escape(self.creator),
           creator_email = escape(self.creator_email),
           contributors = contributors_formated,
           language = self.language,
           publisher = escape(self.publisher),
           subject = escape(self.subject),
           source = escape(self.source),
           rights = escape(self.rights),
           relation = escape(self.relation),
           coverage = escape(self.coverage),

           resource_type = "MLHIM Concept Constraint Definition (CCD)",
           resource_format = "text/xml",
           identifier = self.ccd_id,

           ))


        f.write("<!-- Here are some UUIDs to use for complexType names:\n\n")

        for x in range(0,10):
            f.write("ct_"+str(uuid.uuid4()).replace('-','_')+"\n\n")

        f.write("-->")

        f.close()

    def randomize_uuid(self):
        self.ccd_id = "ccd_"+str(uuid.uuid4()).replace('-','_')

    # Gets info from the metadata panel. Depends on class metadata specifics
    def get_meta_info(self, panel):
        title = panel.text_ctrl_title.GetValue().encode('utf8')
        description = panel.text_ctrl_description.GetValue().encode('utf8')
        creator = panel.text_ctrl_creator.GetValue().encode('utf8')
        creator_email = panel.text_ctrl_creator_email.GetValue().encode('utf8')
        contributor = panel.text_ctrl_contributors.GetValue().encode('utf8')

        publisher = panel.text_ctrl_publisher.GetValue().encode('utf8')
        subject = panel.text_ctrl_subject.GetValue().encode('utf8')
        source = panel.text_ctrl_source.GetValue().encode('utf8')
        rights = panel.text_ctrl_rights.GetValue().encode('utf8')
        relation = panel.text_ctrl_relation.GetValue().encode('utf8')
        coverage = panel.text_ctrl_coverage.GetValue().encode('utf8')

        language = panel.choice_lang.GetStringSelection()

        tempo = panel.datepicker_ctrl_date.GetValue()
        date = '{Y}-{M:02}-{D:02}'.format(Y=tempo.GetYear(), M=tempo.GetMonth()+1, D=tempo.GetDay())

        self.get_info(title, description, date, creator, creator_email, contributor, language, publisher, subject, source, rights, relation, coverage)

###########################################################################
# Misc functions - Maybe put them inside a class in the future
###########################################################################

def help_box(self):

    dlg = wx.MessageDialog(self, """
Emails are formatted as:
Timothy W. Cook <timothywayne.cook@gmail.com>

Separate multiple contributors with a semi-colon and format them as:
Eduardo Cesar <xcesar@gmail.com>; Luciana Cavalini <lutricav@vm.uff.br>
""",
                           'Help',
                           wx.OK | wx.ICON_INFORMATION
                           #wx.YES_NO | wx.NO_DEFAULT | wx.CANCEL | wx.ICON_INFORMATION
                           )
    dlg.ShowModal()
    dlg.Destroy()


def get_lang_list():
    l = list(set(locale.locale_alias.keys()))
    l.sort()
    l2 = [i.replace('_','-')[0:3] + i[3:].upper() for i in l if ((len(i) < 6 and '_' in i) or len(i) == 2)]

    return l2


def get_path(self):
    #wildcard = "CDD files (*.cdd)|*.cdd|"     \
    #    "All files (*.*)|*.*"
    dlg = wx.DirDialog(self, _("Choose a directory to put the generated files:"),
                        os.getcwd(),
                        style=wx.DD_DEFAULT_STYLE
                        )


    if dlg.ShowModal() == wx.ID_OK:
        path = dlg.GetPath()
    else:
        return None

    dlg.Destroy()
    return path


def popup_message(self, msg, tag, icons):
    dlg = wx.MessageDialog(self, msg, tag, icons)
    result = dlg.ShowModal()
    dlg.Destroy()
    if result == wx.ID_OK:
        return True
    else:
        return False


info = Info()

if __name__ == "__main__":
    import gettext
    gettext.install("app") # replace with the appropriate catalog name

    app = wx.PySimpleApp(0)
    wx.InitAllImageHandlers()
    frame_main = MainFrame(None, -1, "")
    app.SetTopWindow(frame_main)
    frame_main.Show()
    app.MainLoop()
